function stat_con

% STAT_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.12 $ $Date: 1998/10/16 23:19:41 $

helpwin('stat_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  stat_con
%
%Double click on any function for more information
%
%  Statistics Toolbox.
%  Version 2.2 (R11) 24-Jul-1998
% 
%  New Features
%    Readme      - Version 2.2 synopsis of new functionality.
% 
%  Distributions.
%  Parameter estimation.
%    betafit     - Beta parameter estimation.
%    binofit     - Binomial parameter estimation.
%    expfit      - Exponential parameter estimation.
%    gamfit      - Gamma parameter estimation.
%    mle         - Maximum likelihood estimation (MLE).
%    normfit     - Normal parameter estimation.
%    poissfit    - Poisson parameter estimation.
%    unifit      - Uniform parameter estimation.
%    weibfit     - Weibull parameter estimation.
% 
%  Probability density functions (pdf).
%    betapdf     - Beta density.
%    binopdf     - Binomial density.
%    chi2pdf     - Chi square density.
%    exppdf      - Exponential density.
%    fpdf        - F density.
%    gampdf      - Gamma density.
%    geopdf      - Geometric density.
%    hygepdf     - Hypergeometric density.
%    lognpdf     - Lognormal density.
%    nbinpdf     - Negative binomial density.
%    ncfpdf      - Noncentral F density.
%    nctpdf      - Noncentral t density.
%    ncx2pdf     - Noncentral Chi-square density.
%    normpdf     - Normal (Gaussian) density.
%    pdf         - Density function for a specified distribution.
%    poisspdf    - Poisson density.
%    raylpdf     - Rayleigh density.
%    tpdf        - T density.
%    unidpdf     - Discrete uniform density.
%    unifpdf     - Uniform density.
%    weibpdf     - Weibull density.
%  
%  Cumulative Distribution functions (cdf).
%    betacdf     - Beta cdf.
%    binocdf     - Binomial cdf.
%    cdf         - Specified cumulative distribution function.
%    chi2cdf     - Chi square cdf.
%    expcdf      - Exponential cdf.
%    fcdf        - F cdf.
%    gamcdf      - Gamma cdf.
%    geocdf      - Geometric cdf.
%    hygecdf     - Hypergeometric cdf.
%    logncdf     - Lognormal cdf.
%    nbincdf     - Negative binomial cdf.
%    ncfcdf      - Noncentral F cdf.
%    nctcdf      - Noncentral t cdf.
%    ncx2cdf     - Noncentral Chi-square cdf.
%    normcdf     - Normal (Gaussian) cdf.
%    poisscdf    - Poisson cdf.
%    raylcdf     - Rayleigh cdf.
%    tcdf        - T cdf.
%    unidcdf     - Discrete uniform cdf.
%    unifcdf     - Uniform cdf.
%    weibcdf     - Weibull cdf.
%  
%  Critical Values of Distribution functions.
%    betainv     - Beta inverse cumulative distribution function.
%    binoinv     - Binomial inverse cumulative distribution function.
%    chi2inv     - Chi square inverse cumulative distribution function.
%    expinv      - Exponential inverse cumulative distribution function.
%    finv        - F inverse cumulative distribution function.
%    gaminv      - Gamma inverse cumulative distribution function.
%    geoinv      - Geometric inverse cumulative distribution function.
%    hygeinv     - Hypergeometric inverse cumulative distribution function.
%    icdf        - Specified inverse cdf.
%    logninv     - Lognormal inverse cumulative distribution function.
%    nbininv     - Negative binomial inverse distribution function.
%    ncfinv      - Noncentral F inverse cumulative distribution function.
%    nctinv      - Noncentral t inverse cumulative distribution function.
%    ncx2inv     - Noncentral Chi-square inverse distribution function.
%    norminv     - Normal (Gaussian) inverse cumulative distribution function.
%    poissinv    - Poisson inverse cumulative distribution function.
%    raylinv     - Rayleigh inverse cumulative distribution function.
%    tinv        - T inverse cumulative distribution function.
%    unidinv     - Discrete uniform inverse cumulative distribution function.
%    unifinv     - Uniform inverse cumulative distribution function.
%    weibinv     - Weibull inverse cumulative distribution function.
% 
%  Random Number Generators.
%    betarnd     - Beta random numbers.
%    binornd     - Binomial random numbers.
%    chi2rnd     - Chi square random numbers.
%    exprnd      - Exponential random numbers.
%    frnd        - F random numbers.
%    gamrnd      - Gamma random numbers.
%    geornd      - Geometric random numbers.
%    hygernd     - Hypergeometric random numbers.
%    lognrnd     - Lognormal random numbers.
%    mvnrnd      - Multivariate normal random numbers.
%    nbinrnd     - Negative binomial random numbers.
%    ncfrnd      - Noncentral F random numbers.
%    nctrnd      - Noncentral t random numbers.
%    ncx2rnd     - Noncentral Chi-square random numbers.
%    normrnd     - Normal (Gaussian) random numbers.
%    poissrnd    - Poisson random numbers.
%    random      - Random numbers from specified distribution.
%    raylrnd     - Rayleigh random numbers.
%    trnd        - T random numbers.
%    unidrnd     - Discrete uniform random numbers.
%    unifrnd     - Uniform random numbers.
%    weibrnd     - Weibull random numbers.
%  
%  Statistics.
%    betastat    - Beta mean and variance.
%    binostat    - Binomial mean and variance.
%    chi2stat    - Chi square mean and variance.
%    expstat     - Exponential mean and variance.
%    fstat       - F mean and variance.
%    gamstat     - Gamma mean and variance.
%    geostat     - Geometric mean and variance.
%    hygestat    - Hypergeometric mean and variance.
%    lognstat    - Lognormal mean and variance.
%    nbinstat    - Negative binomial mean and variance.
%    ncfstat     - Noncentral F mean and variance.
%    nctstat     - Noncentral t mean and variance.
%    ncx2stat    - Noncentral Chi-square mean and variance.
%    normstat    - Normal (Gaussian) mean and variance.
%    poisstat    - Poisson mean and variance.
%    raylstat    - Rayleigh mean and variance.
%    tstat       - T mean and variance.
%    unidstat    - Discrete uniform mean and variance.
%    unifstat    - Uniform mean and variance.
%    weibstat    - Weibull mean and variance.
% 
%  Descriptive Statistics.
%    bootstrp    - Bootstrap statistics for any function.
%    corrcoef    - Correlation coefficient.
%    cov         - Covariance
%    crosstab    - Cross tabulation.
%    geomean     - Geometric mean.
%    grpstats    - Summary statistics by group.
%    harmmean    - Harmonic mean.
%    iqr         - Interquartile range.
%    kurtosis    - Kurtosis.
%    mad         - Median Absolute Deviation.
%    mean        - Sample average (in matlab toolbox).
%    median      - 50th percentile of a sample.
%    moment      - Moments of a sample.
%    nanmax      - Maximum ignoring NaNs.
%    nanmean     - Mean ignoring NaNs.
%    nanmedian   - Median ignoring NaNs.
%    nanmin      - Minimum ignoring NaNs.
%    nanstd      - Standard deviation ignoring NaNs.
%    nansum      - Sum ignoring NaNs.
%    prctile     - Percentiles.
%    range       - Range.
%    skewness    - Skewness.
%    std         - Standard deviation ((in matlab toolbox).
%    tabulate    - Frequency table.
%    trimmean    - Trimmed mean.
%    var         - Variance (in matlab toolbox).
%  
%  Linear Models.
%    anova1      - One-Way Analysis of Variance.
%    anova2      - Two-Way Analysis of Variance.
%    dummyvar    - Dummy-variable coding.
%    leverage    - Regression diagnostic.
%    lscov       - Least-squares estimates with known covariance matrix.
%    polyfit     - Least-squares polynomial fitting.
%    polyval     - Predicted values for polynomial functions.
%    regress     - Multivariate linear regression.
%    regstats    - Regression diagnostics.
%    ridge       - Ridge regression.
%    rstool      - Multidimensional response surface visualization (RSM).
%    stepwise    - Interactive tool for stepwise regression.
%    x2fx        - Factor settings matrix (x) to design matrix (fx).
% 
%  Nonlinear Models
%    nlinfit     - Nonlinear least-squares data fitting (Newton's method).
%    nlintool    - Interactive graphical tool for prediction in nonlinear models.
%    nlpredci    - Confidence intervals for prediction.
%    nlparci     - Confidence intervals for parameters.
%    nnls        - Non-negative least-squares.
% 
%  Cluster Analysis
%    pdist       - Pairwise distance between observations.
%    squareform  - Square matrix formatted distance. 
%    linkage     - Hierachical cluster information.
%    dendrogram  - Generate dendrogram plot.
%    inconsistent- Inconsistent values of a cluster tree.
%    cophenet    - Cophenetic coefficient.
%    cluster     - Construct clusters from LINKAGE output.
%    clusterdata - Construct clusters from data.
% 
%  Design of Experiments (DOE)
%    cordexch    - D-optimal design (coordinate exchange algorithm).
%    daugment    - Augment D-optimal design.
%    dcovary     - D-optimal design with fixed covariates.
%    ff2n        - Two-level full-factorial design.
%    fullfact    - Mixed-level full-factorial design.
%    hadamard    - Hadamard matrices (orthogonal arrays).
%    rowexch     - D-optimal design (row exchange algorithm).
% 
%  Statistical Process Control (SPC)
%    capable     - Capability indices.
%    capaplot    - Capability plot.
%    ewmaplot    - Exponentially weighted moving average plot.
%    histfit     - Histogram with superimposed normal density.
%    normspec    - Plot normal density between specification limits.
%    schart      - S chart for monitoring variability.
%    xbarplot    - Xbar chart for monitoring the mean.
% 
%  Principal Components Analysis
%    barttest    - Bartlett's test for dimensionality.
%    pcacov      - Principal components from covariance matrix.
%    pcares      - Residuals from principal components.
%    princomp    - Principal components analysis from raw data.
% 
%  Multivariate Statistics.
%    classify    - Linear Discriminant Analysis.
%    mahal       - Mahalanobis distance.
% 
%  Hypothesis Tests.
%    ranksum     - Wilcoxon rank sum test (independent samples).
%    signrank    - Wilcoxon sign rank test (paired samples).
%    signtest    - Sign test (paired samples).
%    ztest       - Z test.
%    ttest       - One sample t test.
%    ttest2      - Two sample t test.
% 
%  Statistical Plotting.
%    boxplot     - Boxplots of a data matrix (one per column).
%    fsurfht     - Interactive contour plot of a function.
%    gline       - Point, drag and click line drawing on figures.
%    gname       - Interactive point labelling in x-y plots.
%    lsline      - Add least-square fit line to scatter plot.
%    normplot    - Normal probability plot.
%    qqplot      - Quantile-Quantile plot.
%    refcurve    - Reference polynomial curve.
%    refline     - Reference line.
%    surfht      - Interactive contour plot of a data grid.
%    weibplot    - Weibull probability plot.
%  
%  Statistics Demos.
%    disttool    - GUI tool for exploring probability distribution functions.
%    polytool    - Interactive graph for prediction of fitted polynomials.
%    randtool    - GUI tool for generating random numbers.
%    rsmdemo     - Reaction simulation (DOE, RSM, nonlinear curve fitting).
% 
%  File Based I/O
%    tblread     - Read in data in tabular format.
%    tblwrite    - Write out data in tabular format to file.
%    caseread    - Read in case names.
%    casewrite   - Write out case names to file.
%

function Readme
%MATLAB Tour Partial Function Help:  stat_con
%
%  New Functionality in version 2.2 of the MATLAB Statistics Toolbox.
% 
%  Cluster Analysis
%    pdist       - Pairwise distance between observations.
%    squareform  - Square matrix formatted distance. 
%    linkage     - Hierachical cluster information.
%    dendrogram  - Generate dendrogram plot.
%    inconsistent- Inconsistent values of a cluster tree.
%    cophenet    - Cophenetic coefficient.
%    cluster     - Construct clusters from LINKAGE output.
%    clusterdata - Construct clusters from data.
% 
%  New Functionality in version 2.1 of the MATLAB Statistics Toolbox.
% 
%  Nonparametric Hypothesis Tests.
%     ranksum  - Wilcoxon rank sum test for identical distributions.
%     signrank - Wilcoxon signed rank test for paired samples.
%     signtest - Sign test for paired samples.
% 
%  New Functionality in version 2.0 of the MATLAB Statistics Toolbox.
% 
%  Six new probability distributions.
%  Of particular note are the noncentral versions of the chi-square,
%  F, and t distributions. These are useful for finding the power of 
%  a statistical test for various alternative hypotheses.
%  
%  Parameter Estimation for Probability Distributions
%  Parameter estimates and confidence intervals for eight distributions:
%  beta, binomial, exponential, gamma, normal, Poisson, uniform and Weibull. 
%  
%  Statistical Process Control 
%  Control Charting functions
%      Exponentially weighted moving average (EWMA) plot.
%          Good for monitoring processes subject to mean drift.
%      S chart
%          Time-series plot of the standard deviation of samples.
%      X-bar plot
%          Time-series plot of the means of samples.
%      Capability plots
%          Determines the probability that a new observation will fall 
%          inside the specifications. Based on the assumption that the 
%          process is in control using a trial run of the process.
%      Histogram with fitted normal density.
%          Presentation graphic for showing process location.
%  
%  Design of Experiments (DOE) and Response Surface Methodology (RSM).
%  Factorial and D-optimal designs. Functions for generating designs, 
%  augmenting designs and optimally assigning units with fixed covariates.
% 
%  Nonlinear model fitting.
%  Functions for parameter estimation, interactive prediction and 
%  visualization of multidimensional nonlinear fits, and confidence
%  intervals for parameters and predicted values.
% 
%  Principal Components Analysis.
%  Simplify data analysis by reducing the number of variables.
% 
%  Stepwise Regression
%  Selecting the right variables to include in a multiple regression model.
%  
%  New Statistical Graphic User Interfaces and Plotting Tools
%   rsmdemo  - Demonstration of DOE, response surface modeling,
%              and nonlinear modeling using a simulator of a 
%              chemical reaction.
%   nlintool - Multiple input modeling and interactive graphical
%              prediction for nonlinear models.
%   rstool   - Modeling and interactive graphical prediction for
%              polynomial models with multiple inputs.
%   stepwise - Interactive graphical tool for selecting explanatory
%              variables in regression.
%   regstats - Graphical tool for computing specified regression diagnostics.
%   gname    - Interactive graphical tool for labeling plotted points.
%   gline    - Point and click way to draw a line on a plot.
%   refline  - Specify a reference line on a graph.
%   lsline   - Add least squares fitted line data in a graph.
%   weibplot - Weibull probability plot. 

function betafit
%MATLAB Tour Partial Function Help:  stat_con
%
% BETAFIT Parameter estimates and confidence intervals for beta distributed data.
%    BETAFIT(X) Returns the maximum likelihood estimates of the  
%    parameters of the beta distribution given the data in the vector, X.  
% 
%    [PHAT, PCI] = BETAFIT(X,ALPHA) gives MLEs and 100(1-ALPHA) 
%    percent confidence intervals given the data. By default, the
%    optional paramter ALPHA = 0.05 corresponding to 95% confidence intervals.

function binofit
%MATLAB Tour Partial Function Help:  stat_con
%
% BINOFIT Parameter estimates and confidence intervals for binomial data.
%    BINOFIT(X,N) Returns the estimate of the probability of success 
%    for the binomial distribution given the data in the vector, X.  
% 
%    [PHAT, PCI] = BINOFIT(X,N,ALPHA) gives MLEs and 100(1-ALPHA) 
%    percent confidence intervals given the data. By default, the
%    optional paramter ALPHA = 0.05 corresponding to 95% confidence intervals.

function expfit
%MATLAB Tour Partial Function Help:  stat_con
%
% EXPFIT Parameter estimates and confidence intervals for exponential data.
%    EXPFIT(X) Returns the maximum likelihood estimate of the parameter
%    of the exponential distribution given the data in X. 
% 
%    [MUHAT, MUCI] = EXPFIT(X,ALPHA) gives MLEs and 100(1-ALPHA) 
%    percent confidence intervals given the data. By default, the
%    optional paramter ALPHA = 0.05 corresponding to 95% confidence intervals.

function gamfit
%MATLAB Tour Partial Function Help:  stat_con
%
% GAMFIT Parameter estimates and confidence intervals for gamma distributed data.
%    GAMFIT(X) Returns the maximum likelihood estimates of the  
%    parameters of the gamma distribution given the data in the vector, X.  
% 
%    [PHAT, PCI] = GAMFIT(X,ALPHA) gives MLEs and 100(1-ALPHA) 
%    percent confidence intervals given the data. By default, the
%    optional paramter ALPHA = 0.05 corresponding to 95% confidence intervals.

function mle
%MATLAB Tour Partial Function Help:  stat_con
%
% MLE    Maximum likelihood estimation.
%    PHAT = MLE(DIST,DATA) Returns the maximum likelihood estimates
%    for the distribution specified in DIST using the sample in the
%    vector, DATA.
%    
%    [PHAT, PCI] = MLE(DIST,DATA,ALPHA,P1) Returns the MLEs and 
%    100(1-ALPHA) percent confidence intervals given the data.
%    ALPHA is optional. By default ALPHA = 0.05 which corresponds
%    to 95% confidence intervals. P1 is an extra parameter for use
%    with the binomial distribution for supplying the number of trials.

function normfit
%MATLAB Tour Partial Function Help:  stat_con
%
% NORMFIT Parameter estimates and confidence intervals for normal data.
%    NORMFIT(X,ALPHA) Returns estimates of the parameters of the 
%    normal distribution given the data in X. 
% 
%    [MUHAT,SIGMAHAT,MUCI,SIGMACI] = NORMFIT(X,ALPHA) gives the minimum
%    variance unbiased estimates of the parameters of the normal distribution 
%    and 100(1-ALPHA) percent confidence intervals given the data.
%    By default the optional paramter ALPHA = 0.05 corresponding
%    to 95% confidence intervals. 

function poissfit
%MATLAB Tour Partial Function Help:  stat_con
%
% POISSFIT Parameter estimates and confidence intervals for Poisson data.
%    POISSFIT(X) Returns the estimate of the parameter of the Poisson
%    distribution give the data X. 
% 
%    [LAMBDAHAT, LAMBDACI] = POISSFIT(X,ALPHA) gives MLEs and 100(1-ALPHA) 
%    percent confidence intervals given the data. By default, the
%    optional paramter ALPHA = 0.05 corresponding to 95% confidence intervals.

function unifit
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIFIT Parameter estimates for uniformly distributed data.
%    UNIFIT(X,ALPHA) Returns the maximum likelihood estimates (MLEs) of the  
%    parameters of the uniform distribution given the data in the vector, X.  
% 
%    [AHAT,BHAT,ACI,BCI] = UNIFIT(X,ALPHA) gives MLEs and 
%    100(1-ALPHA) percent confidence intervals given the data.
%    ALPHA is optional. By default ALPHA = 0.05 which corresponds
%    to 95% confidence intervals. 

function weibfit
%MATLAB Tour Partial Function Help:  stat_con
%
% WEIBFIT Parameter estimates and confidence intervals for Weibull data.
%    WEIBFIT(DATA,ALPHA) Returns the maximum likelihood estimates of the  
%    parameters of the Weibull distribution given the data in the vector, DATA.  
% 
%    [PHAT, PCI] = WEIBFIT(DATA,ALPHA) gives MLEs and 100(1-ALPHA) 
%    percent confidence intervals given the data. By default, the
%    optional paramter ALPHA = 0.05 corresponding to 95% confidence intervals.

function betapdf
%MATLAB Tour Partial Function Help:  stat_con
%
% BETAPDF Beta probability density function.
%    Y = BETAPDF(X,A,B) returns the beta probability density 
%    function with parameters A and B at the values in X.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function binopdf
%MATLAB Tour Partial Function Help:  stat_con
%
%  BINOPDF Binomial probability density function.
%    Y = BINOPDF(X,N,P) returns the binomial probability density 
%    function with parameters N and P at the values in X.
%    Note that the density function is zero unless X is an integer.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function chi2pdf
%MATLAB Tour Partial Function Help:  stat_con
%
% CHI2PDF Chi-square probability density function (pdf).
%    Y = CHI2PDF(X,V) returns the chi-square pdf with V degrees  
%    of freedom at the values in X. The chi-square pdf with V 
%    degrees of freedom, is the gamma pdf with parameters V/2 and 2.
% 
%    The size of Y is the common size of X and V. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function exppdf
%MATLAB Tour Partial Function Help:  stat_con
%
% EXPPDF Exponential probability density function.
%    Y = EXPPDF(X,MU) returns the exponential probability density 
%    function with parameter MU at the values in X.
% 
%    The size of Y is the common size of X and MU. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function fpdf
%MATLAB Tour Partial Function Help:  stat_con
%
% FPDF   F probability density function.
%    Y = FPDF(X,V1,V2) returns the F distribution probability density
%    function with V1 and V2 degrees of freedom at the values in X.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function gampdf
%MATLAB Tour Partial Function Help:  stat_con
%
% GAMPDF Gamma probability density function.
%    Y = GAMPDF(X,A,B) returns the gamma probability density function 
%    with parameters A and B, at the values in X.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    Some references refer to the gamma distribution with a single
%    parameter. This corresponds to the default of B = 1.

function geopdf
%MATLAB Tour Partial Function Help:  stat_con
%
% GEOPDF Geometric probability density function (pdf).
%    Y = GEOPDF(X,P) returns the geometric pdf with probability, P, 
%    at the values in X.
% 
%    The size of Y is the common size of X and P. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function hygepdf
%MATLAB Tour Partial Function Help:  stat_con
%
% HYGEPDF Hypergeometric probability density function.
%    Y = HYGEPDF(X,M,K,N) returns the hypergeometric probability 
%    density function at X with integer parameters M, K, and N.
%    Note: The density function is zero unless X is an integer.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function lognpdf
%MATLAB Tour Partial Function Help:  stat_con
%
% LOGNPDF Lognormal probability density function (pdf).
%    Y = LOGNPDF(X,MU,SIGMA) Returns the lognormal pdf at the values
%    in X. The mean and standard deviation of log(Y) are MU and SIGMA.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     
% 
%    Default values for MU and SIGMA are 0 and 1 respectively.

function nbinpdf
%MATLAB Tour Partial Function Help:  stat_con
%
%  NBINPDF Negative binomial probability density function.
%    Y = NBINPDF(X,R,P) returns the negative binomial probability density 
%    function with parameters R and P at the values in X.
%    Note that the density function is zero unless X is an integer.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function ncfpdf
%MATLAB Tour Partial Function Help:  stat_con
%
% NCFPDF Noncentral F probability density function (pdf).
%    Y = NCFPDF(X,NU1,NU2,DELTA) returns the noncentral F pdf with numerator 
%    degrees of freedom (df), NU1, denominator df, NU2, and noncentrality
%    parameter, DELTA, at the values in X.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     

function nctpdf
%MATLAB Tour Partial Function Help:  stat_con
%
% NCTPDF Noncentral T probability density function (pdf).
%    Y = NCTPDF(X,V,DELTA) Returns the noncentral T pdf with V degrees 
%    of freedom and noncentrality parameter, DELTA, at the values in X. 
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     

function ncx2pdf
%MATLAB Tour Partial Function Help:  stat_con
%
% NCX2PDF Noncentral chi-square probability density function (pdf).
%    Y = NCX2PDF(X,V,DELTA) Returns the noncentral chi-square pdf with V 
%    degrees of freedom and noncentrality parameter, DELTA, at the values 
%    in X.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     
% 
%    Some texts refer to this distribution as the generalized Rayleigh,
%    Rayleigh-Rice, or Rice distribution.

function normpdf
%MATLAB Tour Partial Function Help:  stat_con
%
% NORMPDF Normal probability density function (pdf).
%    Y = NORMPDF(X,MU,SIGMA) Returns the normal pdf with mean, MU, 
%    and standard deviation, SIGMA, at the values in X. 
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     
% 
%    Default values for MU and SIGMA are 0 and 1 respectively.

function pdf
%MATLAB Tour Partial Function Help:  stat_con
%
% PDF    Computes a chosen probability density function.
%    Y = PDF(NAME,X,A) returns the named probability density
%    function, which uses parameter A, at the the values in X.
%    Y = PDF(NAME,X,A,B,) returns the named probability density
%    function, which uses parameters A and B, at the the values in X.
%    Similarly for Y = PDF(NAME,X,A,B,C).
% 
%    The name can be: 'beta' or 'Beta', 'bino' or 'Binomial',
%    'chi2' or 'Chisquare','exp' or 'Exponential', 'f' or 'F', 
%    'gam' or 'Gamma','geo' or 'Geometric','hyge' or 'Hypergeometric',
%    'logn' or 'Lognormal','nbin' or 'Negative Binomial',
%    'ncf' or 'Noncentral F','nct' or 'Noncentral t',
%    'ncx2' or 'Noncentral Chi-square'
%    'norm' or 'Normal','poiss' or 'Poisson','rayl' or 'Rayleigh',
%    't' or 'T','unif' or 'Uniform','unid' or 'Discrete Uniform',
%    'weib' or 'Weibull'.
%  
%    PDF calls many specialized routines that do the calculations. 

function poisspdf
%MATLAB Tour Partial Function Help:  stat_con
%
% POISSPDF Poisson probability density function.
%    Y = POISSPDF(X,LAMBDA) returns the Poisson probability density 
%    function with parameter LAMBDA at the values in X.
% 
%    The size of Y is the common size of X and LAMBDA. A scalar input   
%    functions as a constant matrix of the same size as the other input.    
% 
%    Note that the density function is zero unless X is an integer.

function raylpdf
%MATLAB Tour Partial Function Help:  stat_con
%
% RAYLPDF  Rayleigh probability density function.
%    Y = RAYLPDF(X,B) returns the Rayleigh probability density 
%    function with parameter B at the values in X.
% 
%    The size of Y is the common size of X and B. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function tpdf
%MATLAB Tour Partial Function Help:  stat_con
%
%  TPDF  Probability density function (pdf) for Student's T distribution
%    Y = TPDF(X,V) returns the pdf of Student's T distribution with
%    V degrees of freedom, at the values in X.
%    
%    The size of Y is the common size of X and V. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function unidpdf
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIDPDF Uniform (discrete) probability density function (pdf).
%    Y = UNIDPDF(X,N) returns the (discrete) uniform probability 
%    density function on (1,2,...,N) at the values in X.
% 
%    The size of Y is the common size of X and N. A scalar input   
%    functions as a constant matrix of the same size as the other input.    
% 
%    Y is zero (or NaN) unless X is an integer between 1 and N.

function unifpdf
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIFPDF Uniform (continuous) probability density function (pdf).
%    Y = UNIFPDF(X,A,B) returns the continuous uniform pdf on the
%    interval [A,B] at the values in X. By default A = 0 and B = 1.
%    
%    The size of Y is the common size of the input arguments. A scalar input
%    functions as a constant matrix of the same size as the other inputs.    

function weibpdf
%MATLAB Tour Partial Function Help:  stat_con
%
% WEIBPDF Weibull probability density function (pdf).
%    Y = WEIBPDF(X,A,B) returns the Weibull pdf with parameters
%    A and B at the values in X.
% 
%    The size of P is the common size of the input arguments. A scalar input
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    Some references refer to the Weibull distribution with
%    a single parameter, this corresponds to WEIBPDF with A = 1.

function betacdf
%MATLAB Tour Partial Function Help:  stat_con
%
% BETACDF Beta cumulative distribution function.
%    P = BETACDF(X,A,B) returns the beta cumulative distribution
%    function with parameters A and B at the values in X.
% 
%    The size of P is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    BETAINC does the computational work.

function binocdf
%MATLAB Tour Partial Function Help:  stat_con
%
% BINOCDF Binomial cumulative distribution function.
%    Y=BINOCDF(X,N,P) returns the binomial cumulative distribution
%    function with parameters N and P at the values in X.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    The algorithm uses the cumulative sums of the binomial masses.

function cdf
%MATLAB Tour Partial Function Help:  stat_con
%
% CDF    Computes a chosen cumulative distribution function.
%    P = CDF(NAME,X,A1) returns the named cumulative distribution
%    function, which uses parameter A, at the the values in X.
%    P = CDF(NAME,X,A1,A2) returns the named cumulative distribution
%    function, which uses parameters a and b, at the the values in X.
%    Similarly for P = CDF(NAME,X,A1,A2,A3).
% 
%    The name can be: 'beta' or 'Beta', 'bino' or 'Binomial',
%    'chi2' or 'Chisquare','exp' or 'Exponential', 'f' or 'F', 
%    'gam' or 'Gamma','geo' or 'Geometric','hyge' or 'Hypergeometric',
%    'logn' or 'Lognormal','nbin' or 'Negative Binomial',
%    'ncf' or 'Noncentral F','nct' or 'Noncentral t',
%    'ncx2' or 'Noncentral Chi-square'
%    'norm' or 'Normal','poiss' or 'Poisson','rayl' or 'Rayleigh',
%    't' or 'T','unif' or 'Uniform','unid' or 'Discrete Uniform',
%    'weib' or 'Weibull'.
%  
%    CDF calls many specialized routines that do the calculations. 

function chi2cdf
%MATLAB Tour Partial Function Help:  stat_con
%
% CHI2CDF Chi-square cumulative distribution function.
%    P = CHI2CDF(X,V) returns the chi-square cumulative distribution
%    function with V degrees of freedom at the values in X.
%    The chi-square density function with V degrees of freedom,
%    is the same as a gamma density function with parameters V/2 and 2.
% 
%    The size of P is the common size of X and V. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function expcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% EXPCDF Exponential cumulative distribution function.
%    P = EXPCDF(X,MU) returns the exponential cumulative 
%    distribution function with parameter MU at the values in X.
% 
%    The size of P is the common size of X and MU. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function fcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% FCDF   F cumulative distribution function.
%    P = FCDF(X,V1,V2) returns the F cumulative distribution function
%    with V1 and V2 degrees of freedom at the values in X.
% 
%    The size of P is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function gamcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% GAMCDF Gamma cumulative distribution function.
%    P = GAMCDF(X,A,B) returns the gamma cumulative distribution
%    function with parameters A and B at the values in X.
% 
%    The size of P is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    Some references refer to the gamma distribution with a single
%    parameter. This corresponds to the default of B = 1. 
% 
%    GAMMAINC does computational work.

function geocdf
%MATLAB Tour Partial Function Help:  stat_con
%
% GEOCDF Geometric cumulative distribution function.
%    Y=GEOCDF(X,P) returns the geometric cumulative distribution
%    function with probability, P, at the values in X.
% 
%    The size of Y is the common size of X and P. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function hygecdf
%MATLAB Tour Partial Function Help:  stat_con
%
% HYGECDF Hypergeometric cumulative distribution function.
%    P = HYGECDF(X,M,K,N) returns the hypergeometric cumulative 
%    distribution function with parameters M, K, and N 
%    at the values in X.
% 
%    The size of P is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function logncdf
%MATLAB Tour Partial Function Help:  stat_con
%
% LOGNCDF Lognormal cumulative distribution function (cdf).
%    P = LOGNCDF(X,MU,SIGMA) computes the lognormal cdf with mean MU and
%    standard deviation SIGMA at the values in X.
% 
%    The size of P is the common size of X, MU and SIGMA. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    Default values for MU and SIGMA are 0 and 1 respectively.

function nbincdf
%MATLAB Tour Partial Function Help:  stat_con
%
% NBINCDF Negative binomial cumulative distribution function.
%    Y=NBINCDF(X,R,P) returns the negative binomial cumulative distribution
%    function with parameters R and P at the values in X.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    The algorithm uses the cumulative sums of the binomial masses.

function ncfcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% NCFCDF Noncentral F cumulative distribution function (cdf).
%    P = NCFCDF(X,NU1,NU2,DELTA) Returns the noncentral F cdf with numerator 
%    degrees of freedom (df), NU1, denominator df, NU2, and noncentrality
%    parameter, DELTA, at the values in X.
% 
%    The size of P is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     

function nctcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% NCTCDF Noncentral T cumulative distribution function (cdf).
%    P = NCTCDF(X,NU,DELTA) Returns the noncentral T cdf with NU 
%    degrees of freedom and noncentrality parameter, DELTA, at the values 
%    in X.
% 
%    The size of Y is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     

function ncx2cdf
%MATLAB Tour Partial Function Help:  stat_con
%
% NCX2CDF Noncentral chi-square cumulative distribution function (cdf).
%    P = NCX2CDF(X,V,DELTA) Returns the noncentral chi-square cdf with V 
%    degrees of freedom and noncentrality parameter, DELTA, at the values 
%    in X.
% 
%    The size of P is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     
% 
%    Some texts refer to this distribution as the generalized Rayleigh,
%    Rayleigh-Rice, or Rice distribution.

function normcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% NORMCDF Normal cumulative distribution function (cdf).
%    P = NORMCDF(X,MU,SIGMA) computes the normal cdf with mean MU and
%    standard deviation SIGMA at the values in X.
% 
%    The size of P is the common size of X, MU and SIGMA. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    Default values for MU and SIGMA are 0 and 1 respectively.

function poisscdf
%MATLAB Tour Partial Function Help:  stat_con
%
% POISSCDF Poisson cumulative distribution function.
%    P = POISSCDF(X,LAMBDA) computes the Poisson cumulative
%    distribution function with parameter LAMBDA at the values in X.
% 
%    The size of P is the common size of X and LAMBDA. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function raylcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% RAYLCDF  Rayleigh cumulative distribution function.
%    P = RAYLCDF(X,B) returns the Rayleigh cumulative distribution 
%    function with parameter B at the values in X.
% 
%    The size of P is the common size of X and B. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function tcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% TCDF   Student's T cumulative distribution function (cdf).
%    P = TCDF(X,V) computes the cdf for Student's T distribution 
%    with V degrees of freedom, at the values in X.
% 
%    The size of P is the common size of X and V. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function unidcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIDCDF Uniform (discrete) cumulative distribution function.
%    P = UNIDCDF(X,N) returns the cumulative distribution function
%    for a random variable uniform on (1,2,...,N), at the values in X.
% 
%    The size of P is the common size of X and N. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function unifcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIFCDF Uniform (continuous) cumulative distribution function (cdf).
%    P = UNIFCDF(X,A,B) returns the cdf for the uniform distribution
%    on the interval [A,B] at the values in X.
% 
%    The size of P is the common size of the input arguments. A scalar input
%    functions as a constant matrix of the same size as the other inputs.    
%  
%    By default, A = 0 and B = 1.

function weibcdf
%MATLAB Tour Partial Function Help:  stat_con
%
% WEIBCDF Weibull cumulative distribution function (cdf).
%    P = WEIBCDF(X,A,B) returns the Weibull cdf with parameters A and B
%    at the values in X.
% 
%    The size of P is the common size of the input arguments. A scalar input
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    Some references refer to the Weibull distribution with a 
%    single parameter. This corresponds to WEIBCDF with A = 1.

function betainv
%MATLAB Tour Partial Function Help:  stat_con
%
% BETAINV Inverse of the beta cumulative distribution function (cdf).
%    X = BETAINV(P,A,B) returns the inverse of the beta cdf with 
%    parameters A and B at the values in P.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    BETAINV uses Newton's method to converge to the solution.

function binoinv
%MATLAB Tour Partial Function Help:  stat_con
%
% BINOINV Inverse of the binomial cumulative distribution function (cdf).
%    X = BINOINV(Y,N,P) returns the inverse of the binomial cdf with 
%    parameters N and P. Since the binomial distribution is
%    discrete, BINOINV returns the least integer X such that 
%    the binomial cdf evaluated at X, equals or exceeds Y.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    Note that X takes the values 0,1,2,...,N.

function chi2inv
%MATLAB Tour Partial Function Help:  stat_con
%
% CHI2INV Inverse of the chi-square cumulative distribution function (cdf).
%    X = CHI2INV(P,V)  returns the inverse of the chi-square cdf with V  
%    degrees of freedom at the values in P. The chi-square cdf with V 
%    degrees of freedom, is the gamma cdf with parameters V/2 and 2.   
% 
%    The size of X is the common size of P and V. A scalar input
%    functions as a constant matrix of the same size as the other input.   

function expinv
%MATLAB Tour Partial Function Help:  stat_con
%
% EXPINV Inverse of the exponential cumulative distribution function.
%    X = EXPINV(P,MU) returns the inverse of the exponential 
%    cumulative distribution function, with parameter MU,
%    at the values in P.
% 
%    The size of X is the common size of P and MU. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function finv
%MATLAB Tour Partial Function Help:  stat_con
%
% FINV   Inverse of the F cumulative distribution function.
%    X=FINV(P,V1,V2) returns the inverse of the F distribution 
%    function with V1 and V2 degrees of freedom, at the values in P.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function gaminv
%MATLAB Tour Partial Function Help:  stat_con
%
% GAMINV Inverse of the gamma cumulative distribution function (cdf).
%    X = GAMINV(P,A,B)  returns the inverse of the gamma cdf with  
%    parameters A and B, at the probabilities in P.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    GAMINV uses Newton's method to converge to the solution.

function geoinv
%MATLAB Tour Partial Function Help:  stat_con
%
% GEOINV Inverse of the geometric cumulative distribution function.
%    X = GEOINV(Y,P) returns the inverse of the geometric cdf with  
%    parameter P. Since the geometric distribution is discrete, 
%    GEOINV returns the smallest integer X, such that the value of the 
%    cdf at X, equals or exceeds Y.
% 
%    The size of X is the common size of Y and P. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function hygeinv
%MATLAB Tour Partial Function Help:  stat_con
%
% HYGEINV Inverse of the hypergeometric cumulative distribution function (cdf).
%    X = HYGEINV(P,M,K,N) returns the inverse of the hypergeometric 
%    cdf with parameters M, K, and N. Since the hypergeometric 
%    distribution is discrete, HYGEINV returns the smallest integer X, 
%    such that the hypergeometric cdf evaluated at X, equals or exceeds P.   
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function icdf
%MATLAB Tour Partial Function Help:  stat_con
%
% ICDF   Computes a chosen inverse cumulative distribution function.
%    X = ICDF(NAME,P,A) returns the named inverse cumulative distribution
%    function, which uses parameter A, at the the values in X.
%    X = ICDF(NAME,P,A,B) returns the named cumulative distribution
%    function, which uses parameters A and B, at the the values in X.
%    Similarly for X = ICDF(NAME,P,A,B,C).
% 
%    The name can be: 'beta' or 'Beta', 'bino' or 'Binomial',
%    'chi2' or 'Chisquare','exp' or 'Exponential', 'f' or 'F', 
%    'gam' or 'Gamma','geo' or 'Geometric','hyge' or 'Hypergeometric',
%    'logn' or 'Lognormal','nbin' or 'Negative Binomial',
%    'ncf' or 'Noncentral F','nct' or 'Noncentral t',
%    'ncx2' or 'Noncentral Chi-square'
%    'norm' or 'Normal','poiss' or 'Poisson','rayl' or 'Rayleigh',
%    't' or 'T','unif' or 'Uniform','unid' or 'Discrete Uniform',
%    'weib' or 'Weibull'.
%  
%    ICDF calls many specialized routines that do the calculations. 

function logninv
%MATLAB Tour Partial Function Help:  stat_con
%
% LOGNINV Inverse of the lognormal cumulative distribution function (cdf).
%    X = LOGNINV(P,MU,SIGMA) finds the inverse of the lognormal cdf with
%    mean, MU, and standard deviation, SIGMA.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    Default values for MU and SIGMA are 0 and 1 respectively.

function nbininv
%MATLAB Tour Partial Function Help:  stat_con
%
% NBININV Inverse of the negative binomial cumulative distribution function (cdf).
%    X = NBININV(Y,R,P) returns the inverse of the negative binomial cdf with 
%    parameters R and P. Since the negative binomial distribution is discrete,
%    NBININV returns the least integer X such that the negative
%    binomial cdf evaluated at X, equals or exceeds Y.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    

function ncfinv
%MATLAB Tour Partial Function Help:  stat_con
%
% NCFINV Inverse of the noncentral F cumulative distribution function (cdf).
%    X = NCFINV(P,NU1,NU2,DELTA) Returns the inverse of the noncentral F cdf with 
%    numerator degrees of freedom (df), NU1, denominator df, NU2, and noncentrality
%    parameter, DELTA, for the probabilities, P.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     

function nctinv
%MATLAB Tour Partial Function Help:  stat_con
%
% NCTINV Inverse of the noncentral T cumulative distribution function (cdf).
%    X = NCTINV(P,NU,DELTA) Returns the inverse of the noncentral T cdf with 
%    NU degrees of freedom and noncentrality parameter, DELTA, for the  
%    probabilities, P.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.     

function ncx2inv
%MATLAB Tour Partial Function Help:  stat_con
%
% NCX2INV Inverse of the noncentral chi-square cdf.
%    X = NCX2INV(P,V,DELTA)  returns the inverse of the noncentral chi-square   
%    cdf with parameters V and DELTA, at the probabilities in P.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    NCX2INV uses Newton's method to converge to the solution.

function norminv
%MATLAB Tour Partial Function Help:  stat_con
%
% NORMINV Inverse of the normal cumulative distribution function (cdf).
%    X = NORMINV(P,MU,SIGMA) finds the inverse of the normal cdf with
%    mean, MU, and standard deviation, SIGMA.
% 
%    The size of X is the common size of the input arguments. A scalar input  
%    functions as a constant matrix of the same size as the other inputs.    
% 
%    Default values for MU and SIGMA are 0 and 1 respectively.

function poissinv
%MATLAB Tour Partial Function Help:  stat_con
%
% POISSINV Inverse of the Poisson cumulative distribution function (cdf).
%    X = POISSINV(P,LAMBDA) returns the inverse of the Poisson cdf 
%    with parameter lambda. Since the Poisson distribution is discrete,
%    POISSINV returns the smallest value of X, such that the poisson 
%    cdf evaluated, at X, equals or exceeds P.
% 
%    The size of X is the common size of P and LAMBDA. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function raylinv
%MATLAB Tour Partial Function Help:  stat_con
%
% RAYLINV  Inverse of the Rayleigh cumulative distribution function (cdf).
%    X = RAYLINV(P,B) returns the Rayleigh cumulative distribution 
%    function with parameter B at the probabilities in P.

function tinv
%MATLAB Tour Partial Function Help:  stat_con
%
% TINV   Inverse of Student's T cumulative distribution function (cdf).
%    X=TINV(P,V) returns the inverse of Student's T cdf with V degrees 
%    of freedom, at the values in P.
% 
%    The size of X is the common size of P and V. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function unidinv
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIDINV Inverse of uniform (discrete) distribution function.
%    X = UNIDINV(P,N) returns the inverse of the uniform
%    (discrete) distribution function at the values in P.
%    X takes the values (1,2,...,N).
%    
%    The size of X is the common size of P and N. A scalar input   
%    functions as a constant matrix of the same size as the other input.    

function unifinv
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIFINV Inverse of uniform (continuous) distribution function.
%    X = UNIFINV(P,A,B) returns the inverse of the uniform
%    (continuous) distribution funcion on the interval [A,B],
%    at the values in P. By default A = 0 and B = 1.
% 
%    The size of X is the common size of the input arguments. A scalar input
%    functions as a constant matrix of the same size as the other inputs.    

function weibinv
%MATLAB Tour Partial Function Help:  stat_con
%
% WEIBINV Inverse of the Weibull cumulative distribution function (cdf).
%    X = WEIBINV(P,A,B) returns the inverse of the Weibull cdf with
%    parameters A and B, at the values in P.
% 
%    The size of X is the common size of the input arguments. A scalar input
%    functions as a constant matrix of the same size as the other inputs.    

function betarnd
%MATLAB Tour Partial Function Help:  stat_con
%
% BETARND Random matrices from beta distribution.
%    R = BETARND(A,B) returns a matrix of random numbers chosen   
%    from the beta distribution with parameters A and B.
%    The size of R is the common size of A and B if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. Alternatively, R = BETARND(A,B,M,N) returns an M by N matrix. 

function binornd
%MATLAB Tour Partial Function Help:  stat_con
%
%  BINORND Random matrices from a binomial distribution.
%    R = BINORND(N,P,MM,NN)  is an MM-by-NN matrix of random
%    numbers chosen from a binomial distribution with parameters N and P.
% 
%    The size of R is the common size of N and P if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. 
%    Alternatively, R = BINORND(N,P,MM,NN) returns an MM by NN matrix. 
% 
%    The method is direct using the definition of the binomial
%    distribution as a sum of Bernoulli random variables.

function chi2rnd
%MATLAB Tour Partial Function Help:  stat_con
%
% CHI2RND Random matrices from chi-square distribution.
%    R = CHI2RND(V) returns a matrix of random numbers chosen   
%    from the chi-square distribution with V degrees of freedom.
%    The size of R is the size of V.
%    Alternatively, R = CHI2RND(V,M,N) returns an M by N matrix. 

function exprnd
%MATLAB Tour Partial Function Help:  stat_con
%
% EXPRND Random matrices from exponential distribution.
%    R = EXPRND(MU) returns a matrix of random numbers chosen   
%    from the exponential distribution with parameter MU.
%    The size of R is the size of MU.
%    Alternatively, R = EXPRND(MU,M,N) returns an M by N matrix. 

function frnd
%MATLAB Tour Partial Function Help:  stat_con
%
% FRND   Random matrices from the F distribution.
%    R = FRND(V1,V2) returns a matrix of random numbers chosen   
%    from the F distribution with parameters V1 and V2.
%    The size of R is the common size of V1 and V2 if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. Alternatively, R = FRND(V1,V2,M,N) returns an M by N matrix. 

function gamrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% GAMRND Random matrices from gamma distribution.
%    R = GAMRND(A,B) returns a matrix of random numbers chosen   
%    from the gamma distribution with parameters A and B.
%    The size of R is the common size of A and B if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. Alternatively, R = GAMRND(A,B,M,N) returns an M by N matrix. 
% 
%    Some references refer to the gamma distribution
%    with a single parameter. This corresponds to GAMRND
%    with B = 1. (See Devroye, pages 401-402.)

function geornd
%MATLAB Tour Partial Function Help:  stat_con
%
% GEORND Random matrices from geometric distribution.
%    R = GEORND(P) returns a matrix of random numbers chosen from a 
%    geometric distribution where the parameter, P, is the probability  
%    of success in any trial.
% 
%    The size of R is the size of P. Alternatively, 
%    R = GEORND(P,M,N) returns an M by N matrix. 

function hygernd
%MATLAB Tour Partial Function Help:  stat_con
%
% HYGERND Random matrices from a hypergeometric distribution.
%    R = HYGERND(M,K,N) returns a matrix of random numbers chosen from
%    a hypergeometric distribution with parameters M, K, and N.
%    The size of R is the common size of M, K, and N. Alternatively,
%    R = HYGERND(M,K,N,MM,NN) returns an MM by NN matrix.
% 
%    HYGERND uses an inversion method.

function lognrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% LOGNRND Random matrices from the lognormal distribution.
%    R = LOGNRND(MU,SIGMA) returns a matrix of random numbers chosen   
%    from the lognormal distribution with parameters MU and SIGMA.
% 
%    The size of R is the common size of MU and SIGMA if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. Alternatively, R = LOGNRND(MU,SIGMA,M,N) returns an M by N  
%    matrix.

function mvnrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% MVNRND Random matrices from the multivariate normal distribution.
%    R = MVNRND(MU,SIGMA,CASES) returns a matrix of random numbers chosen   
%    from the multivariate normal distribution with mean vector, MU, and 
%    covariance matrix, SIGMA. CASES is the number of rows in R.
% 
%    SIGMA is a symmetric positive definite matrix with size equal to the 
%    length of MU

function nbinrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% NBINRND Random matrices from a negative binomial distribution.
%    RND = NBINRND(R,P,M,N)  is an M-by-N matrix of random
%    numbers chosen from a negative binomial distribution with parameters R and P.
% 
%    The size of RND is the common size of R and P if both are matrices.
%    If either parameter is a scalar, the size of RND is the size of the other
%    parameter. 
%    Alternatively, RND = NBINRND(R,P,M,N) returns an M by N matrix. 

function ncfrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% NCFRND Random matrices from the noncentral F distribution.
%    R = NCFRND(NU1,NU2,DELTA) returns a matrix of random numbers chosen   
%    from the noncentral F distribution with parameters NU1, NU2 and DELTA.
% 
%    The size of R is the common size of NU1, NU2 and DELTA if all are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. Alternatively, R = NCFRND(NU1,NU2,DELTA,M,N) returns an M by N  
%    matrix.

function nctrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% NCTRND Random matrices from noncentral T distribution.
%    R = NCTRND(V,DELTA) returns a matrix of random numbers chosen   
%    from the noncentral T distribution with parameters V and DELTA.
% 
%    The size of R is the common size of V and DELTA if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. Alternatively, R = NCTRND(V,DELTA,M,N) returns an M by N  
%    matrix.

function ncx2rnd
%MATLAB Tour Partial Function Help:  stat_con
%
% NCX2RND Random matrices from the noncentral chi-square distribution.
%    R = NCX2RND(V,DELTA) returns a matrix of random numbers chosen   
%    from the non-central chisquare distribution with parameters V and DELTA.
% 
%    The size of R is the common size of V and DELTA if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. Alternatively, R = NCX2RND(V,DELTA,M,N) returns an M by N  
%    matrix.

function normrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% NORMRND Random matrices from normal distribution.
%    R = NORMRND(MU,SIGMA) returns a matrix of random numbers chosen   
%    from the normal distribution with parameters MU and SIGMA.
% 
%    The size of R is the common size of MU and SIGMA if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. Alternatively, R = NORMRND(MU,SIGMA,M,N) returns an M by N  
%    matrix.

function poissrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% POISSRND Random matrices from Poisson distribution.
%    R = POISSRND(LAMBDA) returns a matrix of random numbers chosen   
%    from the Poisson distribution with parameter LAMBDA.
% 
%    The size of R is the size of LAMBDA. Alternatively, 
%    R = POISSRND(LAMBDA,M,N) returns an M by N matrix. 
% 
%    POISSRND uses a waiting time method.

function random
%MATLAB Tour Partial Function Help:  stat_con
%
% RANDOM Generates random numbers from a named distribution.
%    R = RANDOM(NAME,A,M,N) returns an M-by-N array of random
%    numbers from the named distribution with parameter A.
%    R = RANDOM(NAME,A,B,M,N) returns an M-by-N array of random
%    numbers from the named distribution with parameters A, and B.
%    R = RANDOM(NAME,A,B,C,M,N) returns an M-by-N array of random
%    numbers from the named distribution with parameters A, B, and C.
% 
%    The name can be: 'beta' or 'Beta', 'bino' or 'Binomial',
%    'chi2' or 'Chisquare','exp' or 'Exponential', 'f' or 'F', 
%    'gam' or 'Gamma','geo' or 'Geometric','hyge' or 'Hypergeometric',
%    'logn' or 'Lognormal','nbin' or 'Negative Binomial',
%    'ncf' or 'Noncentral F','nct' or 'Noncentral t',
%    'ncx2' or 'Noncentral Chi-square'
%    'norm' or 'Normal','poiss' or 'Poisson','rayl' or 'Rayleigh',
%    't' or 'T','unif' or 'Uniform','unid' or 'Discrete Uniform',
%    'weib' or 'Weibull'.
%  
%    The default value for both M and N is 1.

function raylrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% RAYLRND Random matrices from Rayleigh distribution.
%    R = RAYLRND(B) returns a matrix of random numbers chosen   
%    from the Rayleigh distribution with parameter B.
% 
%    The size of R is the size of B.
%    Alternatively, R = RAYLRND(B,M,N) returns an M by N matrix. 

function trnd
%MATLAB Tour Partial Function Help:  stat_con
%
% TRND   Random matrices from Student's T distribution.
%    R = TRND(V) returns a matrix of random numbers chosen   
%    from the T distribution with V degrees of freedom.
%    The size of R is the size of V.
%    Alternatively, R = TRND(V,M,N) returns an M by N matrix. 

function unidrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIDRND Random matrices from the discrete uniform distribution.
%    R = UNIDRND(N) returns a matrix of random numbers chosen 
%    uniformly from the set {1, 2, 3, ... ,N}.
% 
%    The size of R is the size of N. Alternatively, 
%    R = UNIDRND(N,MM,NN) returns an MM by NN matrix. 

function unifrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIFRND Random matrices from continuous uniform distribution.
%    R = UNIFRND(A,B) returns a matrix of random numbers chosen   
%    from the continous uniform distribution on the interval from A to B.
%    The size of R is the common size of A and B if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. Alternatively, R = UNIFRND(A,B,M,N) returns an M by N matrix. 

function weibrnd
%MATLAB Tour Partial Function Help:  stat_con
%
% WEIBRND Random matrices from the Weibull distribution.
%    R = WEIBRND(A,B) returns a matrix of random numbers chosen   
%    from the Weibull distribution with parameters A and B.
% 
%    The size of R is the common size of A and B if both are matrices.
%    If either parameter is a scalar, the size of R is the size of the other
%    parameter. R = WEIBRND(A,B,M,N) returns an M by N matrix. 
% 
%    When A == B, WEIBRND calls EXPRND. 
%    When A ~= B, WEIBRND uses an inversion method. 

function betastat
%MATLAB Tour Partial Function Help:  stat_con
%
% BETASTAT Mean and variance for the beta distribution.
%    [M,V] = BETASTAT(A,B) returns the mean and variance 
%    of the beta distribution with parameters A and B.

function binostat
%MATLAB Tour Partial Function Help:  stat_con
%
%  BINOSTAT Mean and variance of the binomial distribution.
%    [M, V] = BINOSTAT(N,P) returns the mean and variance of the
%    binomial distibution with parameters N and P.

function chi2stat
%MATLAB Tour Partial Function Help:  stat_con
%
% CHI2STAT Mean and variance for the chi-square distribution.
%    [M,V] = CHI2STAT(NU) returns the mean and variance 
%    of the chi-square distribution with NU degrees of freedom.
% 
%    A chi-square random variable, with NU degrees of freedom,
%    is identical to a gamma random variable with parameters NU/2 and 2.

function expstat
%MATLAB Tour Partial Function Help:  stat_con
%
% EXPSTAT Mean and variance of the exponential distribution.
%    [M,V] = EXPSTAT(MU) returns the mean and variance 
%    of the exponential distribution with parameter MU.

function fstat
%MATLAB Tour Partial Function Help:  stat_con
%
% FSTAT  Mean and variance for the F distribution.
%    [M,V] = FSTAT(V1,V2) returns the mean (M) and variance (V)
%    of the F distribution with V1 and V2 degrees of freedom.
%    Note that the mean of the F distribution is undefined if V1 
%    is less than 3. The variance is undefined for V2 less than 5.

function gamstat
%MATLAB Tour Partial Function Help:  stat_con
%
% GAMSTAT Mean and variance for the gamma distribution.
%    [M,V] = GAMSTAT(A,B) returns the mean and variance 
%    of the gamma distribution with parameters A and B. By default,
%    B = 1.

function geostat
%MATLAB Tour Partial Function Help:  stat_con
%
% GEOSTAT Mean and variance of the geometric distribution.
%    [M,V] = GEOSTAT(P) returns the mean and variance 
%    of the geometric distribution with parameter P.

function hygestat
%MATLAB Tour Partial Function Help:  stat_con
%
% HYGESTAT Mean and variance for the hypergeometric distribution.
%    [MN,V] = HYGESTAT(M,K,N) returns the mean and variance 
%    of the hypergeometric distribution with parameters M, K, and N.

function lognstat
%MATLAB Tour Partial Function Help:  stat_con
%
% LOGNSTAT Mean and variance for the lognormal distribution.
%    [M,V] = LOGNSTAT(MU,SIGMA) returns the mean and variance of
%    the lognormal distribution with parameters MU and SIGMA.

function nbinstat
%MATLAB Tour Partial Function Help:  stat_con
%
% NBINSTAT Mean and variance of the negative binomial distribution.
%    [M, V] = NBINSTAT(R,P) returns the mean and variance of the
%    negative binomial distibution with parameters R and P.

function ncfstat
%MATLAB Tour Partial Function Help:  stat_con
%
% NCFSTAT Mean and variance for the noncentral F distribution.
%    [M,V] = NCFSTAT(NU1,NU2,DELTA) returns the mean and variance
%    of the noncentral F pdf with NU1 and NU2 degrees of freedom and
%    noncentrality parameter, DELTA.

function nctstat
%MATLAB Tour Partial Function Help:  stat_con
%
% NCTSTAT Mean and variance for the noncentral t distribution.
%    [M,V] = NCTSTAT(NU,DELTA) returns the mean and variance
%    of the noncentral t pdf with NU degrees of freedom and
%    noncentrality parameter, DELTA.

function ncx2stat
%MATLAB Tour Partial Function Help:  stat_con
%
% NCX2STAT Mean and variance for the noncentral chi-square distribution.
%    [M,V] = NCX2STAT(NU,DELTA) returns the mean and variance
%    of the noncentral chi-square pdf with NU degrees of freedom and
%    noncentrality parameter, DELTA.

function normstat
%MATLAB Tour Partial Function Help:  stat_con
%
% NORMSTAT Mean and variance for the normal distribution.
%    [M,V] = NORMSTAT(MU,SIGMA) returns the mean and variance of
%    the normal distribution with parameters MU and SIGMA.

function poisstat
%MATLAB Tour Partial Function Help:  stat_con
%
% POISSTAT Mean and variance for the Poisson distribution.
%    [M,V] = POISSTAT(LAMBDA) returns the mean and variance of
%    the Poisson distribution with parameter LAMBDA.

function raylstat
%MATLAB Tour Partial Function Help:  stat_con
%
% RAYLSTAT Mean and variance for the Rayleigh distribution.
%    [M,V] = RAYLSTAT(B) returns the mean and variance of
%    the Rayleigh distribution with parameter B.

function tstat
%MATLAB Tour Partial Function Help:  stat_con
%
% TSTAT  Mean and variance for the student's t distribution.
%    [MN,V] = TSTAT(NU) returns the mean and variance of
%    Student's T distribution with NU degrees of freedom.

function unidstat
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIDSTAT Mean and variance for uniform (discrete) distribution.
%    [M,V] = UNIDSTAT(N) returns the mean and variance of
%    the (discrete) uniform distribution on {1,2,...,N}

function unifstat
%MATLAB Tour Partial Function Help:  stat_con
%
% UNIFSTAT Mean and variance of the continuous uniform distribution.
%    [M,V] = UNIFSTAT(A,B) returns the mean and variance of
%    the uniform distribution on the interval [A,B].

function weibstat
%MATLAB Tour Partial Function Help:  stat_con
%
% WEIBSTAT Mean and variance for Weibull distribution.
%    [M,V] = WEIBSTAT(A,B) returns the mean and variance of
%    the Weibull distribution with parameters A and B.
% 
%    Some references refer to the Weibull distribution with
%    a single parameter, this corresponds to WEIBSTAT with A = 1.

function bootstrp
%MATLAB Tour Partial Function Help:  stat_con
%
% BOOTSTRP Bootstrap statistics.
%    BOOTSTRP(NBOOT,BOOTFUN,...) draws NBOOT bootstrap data samples and
%    analyzes them using the function, BOOTFUN. NBOOT must be a
%    positive integer. BOOTSTRAP passes the (data) extra arguments to BOOTFUN.
% 
%    [BOOTSTAT,BOOTSAM] = BOOTSTRP(...) Each row of BOOTSTAT contains
%    the results of BOOTFUN on one bootstrap sample. If BOOTFUN
%    returns a matrix, then this output is converted to a long
%    vector for storage in BOOTSTAT. BOOTSAM is a matrix of indices
%    into the row 

function corrcoef
%MATLAB Tour Partial Function Help:  stat_con
%
% CORRCOEF Correlation coefficients.
%    CORRCOEF(X) is a matrix of correlation coefficients formed
%    from array X whose each row is an observation, and each
%    column is a variable.
%    CORRCOEF(X,Y), where X and Y are column vectors is the same as
%    CORRCOEF([X Y]).
%    
%    If C is the covariance matrix, C = COV(X), then CORRCOEF(X) is
%    the matrix whose (i,j)'th element is
% 
%           C(i,j)/SQRT(C(i,i)*C(j,j)).
% 
%    

function cov
%MATLAB Tour Partial Function Help:  stat_con
%
% COV Covariance matrix.
%    COV(X), if X is a vector, returns the variance.  For matrices,
%    where each row is an observation, and each column a variable,
%    COV(X) is the covariance matrix.  DIAG(COV(X)) is a vector of
%    variances for each column, and SQRT(DIAG(COV(X))) is a vector
%    of standard deviations. COV(X,Y), where X and Y are
%    vectors of equal length, is equivalent to COV([X(:) Y(:)]). 
%    
%    COV(X) or COV(X,Y) normalizes by (N-1) where N is the number of
%    observations.  This makes COV(X) the best unbiased estimate of the
%    covariance matrix if the observations are from a normal distribution.
% 
%    COV(X,1) or COV(X,Y,1) normalizes by N and produces the second
%    moment matrix of the observations about their mean.  COV(X,Y,0) is
%    the same as COV(X,Y) and COV(X,0) is the same as COV(X).
% 
%    The mean is removed from each column before calculating the
%    result.
% 
%    

function crosstab
%MATLAB Tour Partial Function Help:  stat_con
%
% CROSSTAB Cross-tabulation of two column vectors.
%    CROSSTAB(COL1,COL2) takes two vectors of positive integers
%    and returns a matrix, TABLE, of crosstabs. Element (i,j) of TABLE
%    contains the count of all instances where COL1 = i and COL2 = j.
%    [TABLE, CHI2, P] = CROSSTAB(COL1,COL2) also returns the chisquare
%    statistic, CHI2, for testing the independence of the rows and 
%    columns TABLE. The scalar, P, is the significance level of the test.
%    Values of P near zero cast doubt on the assumption of independence 
%    of the rows and columns of TABLE.

function geomean
%MATLAB Tour Partial Function Help:  stat_con
%
% GEOMEAN Geometric mean.
%    M = GEOMEAN(X) returns the geometric mean of the input.
%    When X is a vector with n elements, GEOMEAN(X) returns of the 
%    the n-th root of the product of the elements.
%    For a matrix input, GEOMMEAN(X) returns a row vector containing
%    the geometric mean of each column of X.

function grpstats
%MATLAB Tour Partial Function Help:  stat_con
%
% GRPSTATS Summary statistics by group.
%    GRPSTATS(X,GROUP) Returns the MEANS of each column of X by GROUP
%    X is a matrix of observations. GROUP is a vector of  positive integers that
%    indicates the group membership of each row in X. 
% 
%    [MEANS,SEM, COUNTS] = GRPSTATS(X,GROUP) supplies the standard error of the 
%    mean in SEM. COUNTS is the same size as the other outputs. The ith row of 
%    COUNTS contains the number of elements in the ith GROUP. 
% 
%    GRPSTATS(X,GROUP,ALPHA) displays a plot of the means versus index with
%    100(1 - ALPHA)%  confidence intervals around each mean.

function harmmean
%MATLAB Tour Partial Function Help:  stat_con
%
% HARMMEAN Harmonic mean.
%    M = HARMMEAN(X) returns the harmonic mean of the data.
%    The harmonic mean is the inverse of the mean of the inverses 
%    of the elements.
%    For matrix X, HARMMEAN(X) returns a row vector containing
%    the harmonic mean of each column of X.

function iqr
%MATLAB Tour Partial Function Help:  stat_con
%
% IQR    Interquartile Range. 
%    Y = IQR(X) calculates the interquarile range (IQR) of the input.
%    Given a vector input, the IQR is formed by subtracting the 25th 
%    percentile of the data from the 75th percentile of the data.
%    (See PRCTILE)
% 
%    The IQR is a robust estimate of the spread of the data since changes
%    in the upper and lower 25% of the data do not affect it.

function kurtosis
%MATLAB Tour Partial Function Help:  stat_con
%
% KURTOSIS Kurtosis. 
%    For vectors, KURTOSIS(x) returns the sample kurtosis.  
%    For matrices, KURTOSIS(X)is a row vector containing the sample
%    kurtosis of each column. The kurtosis is the fourth central 
%    moment divided by fourth power of the standard deviation.
% 
%    

function mad
%MATLAB Tour Partial Function Help:  stat_con
%
% MAD    Mean absolute deviation. 
%    Y = MAD(X) calculates the mean absolute deviation (MAD) of X.
%    For matrix X, MAD returns a row vector containing the MAD of each  
%    column.
% 
%    The algorithm involves subtracting the mean of X from X,
%    taking absolute values, and then finding the mean of the result.

function mean
%MATLAB Tour Partial Function Help:  stat_con
%
% MEAN   Average or mean value.
%    For vectors, MEAN(X) is the mean value of the elements in X. For
%    matrices, MEAN(X) is a row vector containing the mean value of
%    each column.  For N-D arrays, MEAN(X) is the mean value of the
%    elements along the first non-singleton dimension of X.
% 
%    MEAN(X,DIM) takes the mean along the dimension DIM of X. 
% 
%    Example: If X = [0 1 2
%                     3 4 5]
% 
%    then mean(X,1) is [1.5 2.5 3.5] and mean(X,2) is [1
%                                                      4]
% 
%    

function median
%MATLAB Tour Partial Function Help:  stat_con
%
% MEDIAN Median value.
%    For vectors, MEDIAN(X) is the median value of the elements in X.
%    For matrices, MEDIAN(X) is a row vector containing the median
%    value of each column.  For N-D arrays, MEDIAN(X) is the median
%    value of the elements along the first non-singleton dimension
%    of X.
% 
%    MEDIAN(X,DIM) takes the median along the dimension DIM of X.
% 
%    Example: If X = [0 1 2
%                     3 4 5]
% 
%    then median(X,1) is [1.5 2.5 3.5] and median(X,2) is [1
%                                                          4]
% 
%    

function moment
%MATLAB Tour Partial Function Help:  stat_con
%
%  MOMENT Central moments of all orders.
%    MOMENT(DATA,ORDER) returns the central moment of DATA 
%    specified by the positive integer, ORDER.
%    For matrix, DATA, MOMENT returns central moments of the  
%    specified order for each column in DATA.
%    Note: the central first moment is zero. Also the 
%    central second moment is the variance using a divisor
%    of N instead of N-1 where N is the sample size.
% 
%    

function nanmax
%MATLAB Tour Partial Function Help:  stat_con
%
% NANMAX Maximum ignoring NaNs.
%    M = NANMAX(A) returns the maximum with NaNs treated as missing. 
%    For vectors, NANMAX(A) is the largest non-NaN element in A. For
%    matrices, NANMAX(A) is a row vector containing the maximum non-NaN
%    element from each column. 
% 
%    [M,NDX] = NANMAX(A) also returns the indices of the maximum 
%    values in vector NDX.
% 
%    M = NANMAX(A,B) returns the larger of A or B which must match in size.
% 
%    

function nanmean
%MATLAB Tour Partial Function Help:  stat_con
%
% NANMEAN Average or mean ignoring NaNs.
%    NANMEAN(X) returns the average treating NaNs as missing values.  
%    For vectors, NANMEAN(X) is the mean value of the non-NaN
%    elements in X.  For matrices, NANMEAN(X) is a row vector
%    containing the mean value of each column, ignoring NaNs.
% 
%    

function nanmedian
%MATLAB Tour Partial Function Help:  stat_con
%
% NANMEDIAN NaN protected median value.
%    NANMEDIAN(X) returns the median treating NaNs as missing values.
%    For vectors, NANMEDIAN(X) is the median value of the non-NaN
%    elements in X.  For matrices, NANMEDIAN(X) is a row vector
%    containing the median value of each column, ignoring NaNs.
% 
%    

function nanmin
%MATLAB Tour Partial Function Help:  stat_con
%
% NANMIN NaN protected minimum.
%    M = NANMIN(A) returns the minimum with NaNs treated as missing values. 
%    For vectors, NANMIN(A) is the smallest non-NaN element in A. For
%    matrices, NANMIN(A) is a vector containing the minimum non-NaN
%    element from each column. 
% 
%    [M, NDX] = NANMIN(A) also returns the indices of the minimum values
%    in vector NDX.
% 
%    M = NANMIN(A,B) returns the smaller of A or B which must match in size.
% 
%    

function nanstd
%MATLAB Tour Partial Function Help:  stat_con
%
% NANSTD Standard deviation ignoring NaNs.
%    NANSTD(X) returns the same standard deviation treating NaNs 
%    as missing values.
% 
%    For vectors, NANSTD(X) is the standard deviation of the
%    non-NaN elements in X.  For matrices, NANSTD(X) is a row
%    vector containing the standard deviation of each column,
%    ignoring NaNs.
% 
%    

function nansum
%MATLAB Tour Partial Function Help:  stat_con
%
% NANSUM Sum ignoring NaNs.
%    NANSUM(X) returns the sum treating NaNs as missing values.  
%    For vectors, NANSUM(X) is the sum of the non-NaN elements in
%    X. For matrices, NANSUM(X) is a row vector containing the sum 
%    of the non-NaN elements in each column of X. 
% 
%     

function prctile
%MATLAB Tour Partial Function Help:  stat_con
%
% PRCTILE gives the percentiles of the sample in X.
%    Y = PRCTILE(X,P) returns a value that is greater than P percent
%    of the values in X. For example, if P = 50  Y is the median of X. 
% 
%    P may be either a scalar or a vector. For scalar P, Y is a row   
%    vector containing Pth percentile of each column of X. For vector P,
%    the ith row of Y is the P(i) percentile of each column of X.

function range
%MATLAB Tour Partial Function Help:  stat_con
%
% RANGE  The range is the difference between the maximum and minimum values. 
%    Y = RANGE(X) calculates the range of the input.
%    For matrices RANGE(X) is a vector containing the range for each column.

function skewness
%MATLAB Tour Partial Function Help:  stat_con
%
% SKEWNESS Skewness. 
%    For vectors, SKEWNESS(x) returns the sample skewness.  
%    For matrices, SKEWNESS(X)is a row vector containing the sample
%    skewness of each column. The skewness is the third central 
%    moment divided by the cube of the standard deviation.
% 
%    

function std
%MATLAB Tour Partial Function Help:  stat_con
%
% STD    Standard deviation.
%    For vectors, STD(X) returns the standard deviation. For matrices,
%    STD(X) is a row vector containing the standard deviation of each
%    column.  For N-D arrays, STD(X) is the standard deviation of the
%    elements along the first non-singleton dimension of X.
% 
%    STD(X) normalizes by (N-1) where N is the sequence length.  This
%    makes STD(X).^2 the best unbiased estimate of the variance if X
%    is a sample from a normal distribution.
% 
%    STD(X,1) normalizes by N and produces the second moment of the
%    sample about its mean.  STD(X,0) is the same as STD(X).
% 
%    STD(X,FLAG,DIM) takes the standard deviation along the dimension
%    DIM of X.  When FLAG=0 STD normalizes by (N-1), otherwise STD
%    normalizes by N.
% 
%    Example: If X = [4 -2 1
%                     9  5 7]
%      then std(X,0,1) is [ 3.5355 4.9497 4.2426] and std(X,0,2) is [3.0
%                                                                    2.0]
%    

function tabulate
%MATLAB Tour Partial Function Help:  stat_con
%
% TABULATE Frequency table.
%    TABLE = TABULATE(X) takes a vector of positive integers, X,  
%    and returns a matrix, TABLE. 
%    The first column of TABLE is the values of X. The second
%    is the number of instances of this value. The last column
%    contains the percentage of each value.
%    TABULATE with no output arguments returns a formatted table
%    in the command window.
%    

function trimmean
%MATLAB Tour Partial Function Help:  stat_con
%
% TRIMMEAN The trimmed mean of X is a robust estimate of the sample location.
%    M = TRIMMEAN(X,PERCENT) calculates the mean of X excluding the highest
%    and lowest percent/2 of the data. For matrices, TRIMMEAN(X) is a vector
%    containing the trimmed mean for each column. The scalar, PERCENT, 
%    must take values between 0 and 100.
% 
%    For matrix, X, M = TRIMMEAN(X,PERCENT) is a row vector containing the
%    trimmed mean for each column of X.   

function var
%MATLAB Tour Partial Function Help:  stat_con
%
% VAR    Variance. 
%    For vectors, VAR(X) returns the variance of X.  
%    For matrices, VAR(X)is a row vector containing the
%    variance of each column of X. 
% 
%    VAR(X) normalizes by N-1 where N is the sequence length.  This
%    makes VAR(X) the best unbiased estimate of the variance if X
%    is a sample from a normal distribution.
% 
%    VAR(X,1) normalizes by N and produces the second moment of the
%    sample about its mean.
% 
%    VAR(X,W) computes the variance using the weight vector, W.
%    The number of elements in W must equal the number of rows 
%    in X unless W = 1 which is treated as a short-cut for a 
%    vector of ones.
% 
%    The elements of W must be positive. VAR normalizes W by
%    dividing each element in W by the sum of all its elements.
% 
%    The variance is the square of the standard deviation
%    (STD). 
% 
%    

function anova1
%MATLAB Tour Partial Function Help:  stat_con
%
% ANOVA1 One-way analysis of variance (ANOVA).
%    ANOVA1 performs a one-way ANOVA for comparing the means of two or more 
%    groups of data. It returns the p-value for the null hypothesis that the
%    means of the groups are equal.
% 
%    P = ANOVA1(X) for matrix, X, treats each column as a separate group,  
%    and determines whether the population means of the columns are equal.   
%    This one-input form of ANOVA1 is appropriate when each group has the
%    same number of elements (balanced ANOVA).
% 
%    P = ANOVA1(X,GROUP) has vector inputs X and GROUP. The vector, GROUP, 
%    identifies the group of the corresponding element of X. This two-input
%    form of ANOVA1 has no restrictions on the number of elements in each
%    group.    
%  
%    ANOVA1 prints the standard one-way ANOVA table in Figure 1 and displays 
%    a boxplot in Figure2.

function anova2
%MATLAB Tour Partial Function Help:  stat_con
%
% ANOVA2 Two-way analysis of variance.
%    ANOVA2(X,REPS) performs a balanced two-way ANOVA for comparing the
%    means of two or more columns and two or more rows of the sample in X.
%    The data in different columns represent changes in one factor. The data
%    in different rows represent changes in the other factor. If there is 
%    more than one observation per row-column pair, then the argument, REPS,
%    indicates the number of observations per "cell". A cell contains REPS 
%    number of rows.
% 
%    For example, if REPS = 3, then each cell contains 3 rows and the total
%    number of rows must be a multiple of 3. If X has 12 rows, and REPS = 3,
%    then the "row" factor has 4 levels (3*4 = 12). The second level of the 
%    row factor goes from rows 4 to 6.  

function dummyvar
%MATLAB Tour Partial Function Help:  stat_con
%
% DUMMYVAR Dummy variable coding.
%    DUMMYVAR(GROUP) makes a dummy column for
%    each unique value in each column of the 
%    matrix GROUP. The values of the elements
%    in any column of GROUP go from one to the
%    number of members in the group.

function leverage
%MATLAB Tour Partial Function Help:  stat_con
%
% LEVERAGE Regression diagnostic.
%    LEVERAGE(DATA,MODEL) finds the leverage on a regression of each
%    row (point) in the matrix, DATA. The argument, MODEL, controls the 
%    order of the regression model. By default, LEVERAGE assumes a linear 
%    additive model with a constant term. MODEL can be following strings:
%    interaction - includes constant, linear, and cross product terms.
%    quadratic - interactions plus squared terms.
%    purequadratic - includes constant, linear and squared terms.

function lscov
%MATLAB Tour Partial Function Help:  stat_con
%
% LSCOV Least squares with known covariance.
%    X = LSCOV(A,B,V) returns the vector X that solves A*X = B + E
%    where E is normally distributed with zero mean and covariance V.
%    A must be M-by-N where M > N.  This is the over-determined
%    least squares problem with covariance V of the data.  
%    The solution is found without inverting V.
% 
%    The vector X minimizes (A*X-B)'*inv(V)*(A*X-B). The classical
%    linear algebra solution to this problem is:
% 
%        X = inv(A'*inv(V)*A)*A'*inv(V)*B
% 
%    [X, DX] = LSCOV(A,B,V) returns the standard errors of X in DX. 
%    The standard statistical formula for the standard error of the
%    coefficients is:
% 
%       mse = B'*(inv(V) - inv(V)*A*inv(A'*inv(V)*A)*A'*inv(V))*B./(m-n) 
%       dx = sqrt(diag(inv(A'*inv(V)*A)*mse))
% 
%    

function polyfit
%MATLAB Tour Partial Function Help:  stat_con
%
% POLYFIT Fit polynomial to data.
%    POLYFIT(X,Y,N) finds the coefficients of a polynomial P(X) of
%    degree N that fits the data, P(X(I))~=Y(I), in a least-squares sense.
% 
%    [P,S] = POLYFIT(X,Y,N) returns the polynomial coefficients P and a
%    structure S for use with POLYVAL to obtain error estimates on
%    predictions.  If the errors in the data, Y, are independent normal
%    with constant variance, POLYVAL will produce error bounds which
%    contain at least 50% of the predictions.
% 
%    The structure S contains the Cholesky factor of the Vandermonde
%    matrix (R), the degrees of freedom (df), and the norm of the
%    residuals (normr) as fields.   
% 
%    

function polyval
%MATLAB Tour Partial Function Help:  stat_con
%
% POLYVAL Evaluate polynomial.
%    Y = POLYVAL(P,X), when P is a vector of length N+1 whose elements
%    are the coefficients of a polynomial, is the value of the
%    polynomial evaluated at X.
% 
%        Y = P(1)*X^N + P(2)*X^(N-1) + ... + P(N)*X + P(N+1)
% 
%    If X is a matrix or vector, the polynomial is evaluated at all
%    points in X.  

function regress
%MATLAB Tour Partial Function Help:  stat_con
%
% REGRESS Multiple linear regression using least squares.
%    b = REGRESS(y,X) returns the vector of regression coefficients, B.
%    Given the linear model: y = Xb, 
%    (X is an nxp matrix, y is the nx1 vector of observations.) 
%    [B,BINT,R,RINT,STATS] = REGRESS(y,X,alpha) uses the input, ALPHA
%    to calculate 100(1 - ALPHA) confidence intervals for B and the 
%    residual vector, R, in BINT and RINT respectively. 
%    The vector STATS contains the R-square statistic along with the F 
%    and p values for the regression.

function regstats
%MATLAB Tour Partial Function Help:  stat_con
%
% REGSTATS Regression diagnostics for linear models.
%    REGSTATS(RESPONSES,DATA,MODEL) fits a multiple regression of the
%    measurements in the vector, RESPONSES on the values in the matrix,
%    DATA. The function creates a UI that displays a group of checkboxes
%    that save diagnostic statistics to the base workspace using specified
%    variable names. MODEL, controls the order of the regression
%    model. By default, REGSTATS uses a linear additive model
%    with a constant term. MODEL can be following strings:
%    interaction - includes constant, linear, and cross product terms.
%    quadratic - interactions plus squared terms.
%    purequadratic - includes constant, linear and squared terms.

function ridge
%MATLAB Tour Partial Function Help:  stat_con
%
% RIDGE Ridge regression.
%    B = RIDGE(Y,X,K) returns the vector of regression coefficients, B.
%    Given the linear model: y = Xb, 
%    X is an n by p matrix, y is the n by 1 vector of observations and k
%    is a scalar constant.

function rstool
%MATLAB Tour Partial Function Help:  stat_con
%
% RSTOOL Interactive fit and plot of a multidimiensional response surface (RSM).
%    RSTOOL(X,Y,MODEL,ALPHA) is a prediction plot that provides a 
%    multiple input polynomial fit to (X,y) data. It plots a 100(1 - ALPHA) 
%    percent global confidence interval for predictions as two red curves. 
%    The default model is linear. MODEL can be following strings:
%    interaction - includes constant, linear, and cross product terms.
%    quadratic - interactions plus squared terms.
%    purequadratic - includes constant, linear and squared terms.
%    The default value for ALPHA is 0.05, which produces 95% confidence 
%    intervals.
% 
%    RSTOOL(X,Y,MODEL,ALPHA,XNAME,YNAME) The optional inputs XNAME and 
%    YNAME contain strings for the X and Y variables respectively.
% 
%    Drag the dotted white reference line and watch the predicted
%    values update simultaneously. Alternatively, you can get a specific
%    prediction by typing the "X" value into an editable text field.
%    Use the pop-up menu labeled model to interactively change the model.
%    Use the pop-up menu labeled Export to move specified variables to
%    the base workspace.

function stepwise
%MATLAB Tour Partial Function Help:  stat_con
%
% STEPWISE Interactive tool for stepwise regression.
%    STEPWISE(X,Y,INMODEL,ALPHA) fits a regression model of Y on the
%    columns of X specified in the vector INMODEL. ALPHA is the significance 
%    for testing each term in the model. By default, 
%    ALPHA = 1 - (1 - 0.025).^(1/p) where p is the number of columns in X.
%    This translates to plotted 95% simultaneous confidence intervals
%    (Bonferroni) for all the coefficients.
% 
%    The least squares coefficient is plotted with a green filled circle.
%    A coefficient is not significantly different from zero if its confidence
%    interval crosses the white zero line. Significant model terms are plotted
%    using solid lines. Terms not significantly different from zero are plotted 
%    with dotted lines.
% 
%    Click on the confidence interval lines to toggle the state of the model
%    coefficients. If the confidence interval line is green the term is in the model.
%    If the the confidence interval line is red the term is not in the model.
%    Use the pop-up menu, Export, to move variables to the base workspace.
% 
%    Reference: Draper, Norman and Smith, Harry, Applied Regression Analysis,
%    Second Edition, John Wiley & Sons, Inc. 1981 pp. 307-312.

function x2fx
%MATLAB Tour Partial Function Help:  stat_con
%
% X2FX   Factor settings matrix (x) to design matrix (fx).
%    D = X2FX(X,'MODEL') Transforms a matrix of system inputs, X, to 
%    the design matrix for a regression analysis. The optional string
%    input, MODEL, controls the order of the regression model. By 
%    default, X2FX returns the design matrix for a linear additive
%    model with a constant term. MODEL can be following strings:
%    interaction (i)   - includes constant, linear, and cross product terms.
%    quadratic (q)     - interactions plus squared terms.
%    purequadratic (p) - includes constant, linear and squared terms.
%    
%    Alternatively, MODEL can be a matrix of terms. Each row of MODEL 
%    represents one term. The value in a column is the exponent to raise 
%    the same column in X for that term. D(i,j) = prod(x(i,:).^model(j,:)). 
%    This allows for models with polynomial terms of arbitrary order.
% 
%    Example: x = [1 2 3]' model = [0 1 2]'
%    D = [1 1 1; 1 2 4; 1 3 9] 
%    The first column is x to the 0th power. The second column is x to
%    the 1st power. And the last column is x squared.
%  
%    X2FX is a utility function for RSTOOL, REGSTATS and CORDEXCH.
%    

function nlinfit
%MATLAB Tour Partial Function Help:  stat_con
%
% NLINFIT Nonlinear least-squares data fitting by the Gauss-Newton method.
%    NLINFIT(X,Y,'MODEL',BETA0) finds the coefficients of the nonlinear 
%    function described in MODEL. MODEL is a user supplied function having 
%    the form y = f(beta,x). That is MODEL returns the predicted values of y
%    given initial parameter estimates, beta, and the independent variable, X.   
%    [BETA,R,J] = NLINFIT(X,Y,'MODEL',BETA0) returns the fitted coefficients
%    BETA the residuals, R, and the Jacobian, J, for use with NLINTOOL to
%    produce error estimates on predictions.

function nlintool
%MATLAB Tour Partial Function Help:  stat_con
%
% NLINTOOL Interactive graphical tool for nonlinear fitting and prediction.
%    NLINTOOL(X,Y,MODEL,BETA0,ALPHA) is a prediction plot that provides a 
%    nonlinear curve fit to (x,y) data. It plots a 100(1 - ALPHA) percent
%    global confidence interval for predictions as two red curves. BETA0 is
%    a vector containing initial guesses for the parameters. 
%    The default value for ALPHA is 0.05, which produces 95% confidence
%    intervals. 
% 
%    NLINTOOL(X,Y,MODEL,BETA0,ALPHA,XNAME,YNAME) The optional inputs XNAME  
%    and YNAME contain strings for the X and Y variables respectively.
% 
%    You can drag the dotted white reference line and watch the predicted
%    values update simultaneously. Alternatively, you can get a specific
%    prediction by typing the "X" value into an editable text field.
%    Use the pop-up menu labeled Export to move specified variables to
%    the base workspace.

function nlpredci
%MATLAB Tour Partial Function Help:  stat_con
%
% NLPREDCI Confidence intervals for nonlinear least squares prediction.
%    [YPRED, DELTA] = NLPREDCI(MODEL,INPUTS,X,F,J) returns predictions, 
%    YPRED, and 95% confidence interval delta on the nonlinear least
%    squares prediction X, given the residuals, F, and the Jacobian, J.   
% 
%    The confidence interval calculation is valid for systems where the 
%    length of F exceeds the length of X and J has full column rank at X. 
% 
%    NLPREDCI uses the outputs of NLINFIT for its inputs.
%    Example:
%       [x,f,J]  = nlinfit(input,output,model,xinit);
%       [yp, ci[ = nlpredci(model,input,x,f,J);
% 
%    

function nlparci
%MATLAB Tour Partial Function Help:  stat_con
%
% NLPARCI Confidence intervals on parameters of nonlinear models.
%    CI = NLPARCI(X,F,J) returns the 95% confidence interval CI
%    on the nonlinear least squares parameter estimate X, given the 
%    residual sum of squares, F, and the Jacobian matrix ,J, at the solution.
% 
%    The confidence interval calculation is valid for systems where 
%    the number of rows of J exceeds the length of X. 
% 
%    NLPARCI uses the outputs of NLINFIT for its inputs.
%    Example:
%       [x,f,J]=nlinfit(input,output,model,xinit);
%       ci = nlparci(x,f,J);
% 
%    

function nnls
%MATLAB Tour Partial Function Help:  stat_con
%
% NNLS   Non-negative least-squares.
%    NNLS has been replaced with LSQNONNEG.  NNLS currently works but  
%    will be removed in the future.  Use LSQNONNEG instead.
% 
%    X = NNLS(A,b) returns the vector X that minimizes NORM(A*X - b)
%    subject to X >= 0.   A and b must be real.
% 
%    A default tolerance of TOL = MAX(SIZE(A)) * NORM(A,1) * EPS
%    is used for deciding when elements of X are less than zero.
%    This can be overridden with X = NNLS(A,b,TOL).
% 
%    [X,W] = NNLS(A,b) also returns dual vector W where w(i) < 0
%    when x(i) = 0 and w(i) is approximately 0 when x(i) > 0.
% 
%    

function pdist
%MATLAB Tour Partial Function Help:  stat_con
%
% PDIST Pairwise distance between observations.
%    Y = PDIST(X,METRIC) returns a vector which contains all the
%    distances between each pair of observations in X computed using
%    the given METRIC.  X is a M by N matrix, treated as M observations
%    of N variables. Since there are M*(M-1)/2 pairs of observations in
%    X, the size of Y is M*(M-1)/2 by 1.  The default metric is
%    'EUCLID'.  The available metrics are:
% 
%       'euclid'    --- Euclidean metric
%       'seuclid'   --- Standardized Euclid metric
%       'cityblock' --- City Block metric
%       'mahal'     --- Mahalanobis metric
%       'minkowski' --- Minkowski metric
% 
%    Y = PDIST(X, 'minkowski', p) specifies the exponents in the
%    'Minkowski' computation. When p is not given, p is set to 2.
% 
%    The output Y is arranged in the order of ((1,2),(1,3),..., (1,M),
%    (2,3),...(2,M),.....(M-1,M)).  i.e. the upper right triangle of
%    the M by M square matrix. To get the distance between observation
%    i and observation j, either use the formula Y((i-1)*(M-i/2)+j-i)
%    or use the helper function Z = SQUAREFORM(Y), which will return a
%    M by M symmetric square matrix, with Z(i,j) equaling the distance
%    between observation i and observation j.
% 
%    

function squareform
%MATLAB Tour Partial Function Help:  stat_con
%
% SQUAREFORM Square matrix formatted distance. 
%    Z = squareform(Y) converts the output of PDIST function into a 
%    square format, so that Z(i,j) denotes the distance between the
%    i and j objects in the original data.
% 
%    

function linkage
%MATLAB Tour Partial Function Help:  stat_con
%
% LINKAGE Hierarchical cluster information.
%    LINKAGE(Y) computes the hierarchical cluster information, using the
%    single linkage algorithm, from a given distance matrix Y generated
%    by PDIST. Y is also commonly known as similarity or
%    dissimilarity matrix.
% 
%    LINKAGE(Y, method) computes the hierarchical cluster information using
%    the specified algorithm. The available methods are:
% 
%       'single'   --- nearest distance
%       'complete' --- furthest distance
%       'average'  --- average distance
%       'centroid' --- center of mass distance
%       'ward'     --- inner squared distance
% 
%    Cluster information will be returned in the matrix Z with size m-1
%    by 3.  Column 1 and 2 of Z contain cluster indices linked in pairs
%    to form a binary tree. The leaf nodes are numbered from 1 to
%    m. They are the singleton clusters from which all higher clusters
%    are built. Each newly-formed cluster, corresponding to Z(i,:), is
%    assigned the index m+i, where m is the total number of initial
%    leaves. Z(i,1:2) contains the indices of the two component
%    clusters which form cluster m+i. There are n-1 higher clusters
%    which correspond to the interior nodes of the output clustering
%    tree. Z(i,3) contains the corresponding linkage distances between
%    the two clusters which are merged in Z(i,:), e.g. if there are
%    total of 30 initial nodes, and at step 12, cluster 5 and cluster 7
%    are combined and their distance at this time is 1.5, then row 12
%    of Z will be (5,7,1.5). The newly formed cluster will have an
%    index 12+30=42. If cluster 42 shows up in a latter row, that means
%    this newly formed cluster is being combined again into some bigger
%    cluster.
% 
%    

function dendrogram
%MATLAB Tour Partial Function Help:  stat_con
%
% DENDROGRAM Generate dendragram plot.
%    DENDROGRAM(Z) generates a dendrogram from the output matrix of
%    LINKAGE.  Z is a (M-1) by 3 matrix. M is the number of
%    observations in the original data. 
% 
%    A dendrogram consists of many upsidedown U shape lines connecting
%    nodes in a hierachichale tree. Except for the WARD linkage (see
%    LINKAGE), the height of each U is the distance between the two
%    clusters to be connected at that time.  
% 
%    DENDROGRAM(Z,P) generate a dendrogram with only the top P nodes.
%    When there are more than 30 nodes in the original data, the
%    dendrogram may look crowded. The default value of P is 30. If P =
%    0, then, every node will be displayed.
% 
%    H = DENDROGRAM(...) returns a vector of line handles.
% 
%    [H, T] = DENDROGRAM(...) also returns T, a vector of size M that
%    contains cluster number for each observation in the original data.
% 
%    When bottom leaves are cutoff, some information are lost. T
%    supplies this lost information. For example, to find out which
%    observations are contained in node k of the dendrogram, use
%    FIND(T==k). 
% 
%    When there are less than P observations in the original data, T
%    is the identical map, i.e. T = (1:M)'. Each node only contains
%    itself.
% 
%    

function cophenet
%MATLAB Tour Partial Function Help:  stat_con
%
% COPHENET Cophenetic coefficient.
%    C = COPHENETIC(Z,Y) computes the Cophenetic coefficient between the
%    distance of the cluster tree in Z and the distance in Y. Z is the
%    output of the function LINKAGE. Y is the output of the function
%    PDIST.
% 
%    The Cophenetic coefficient is defined as
%    
%                     sum((Z(i,j)-z)*(Y(i,j)-y)) 
%                     i<j             
%        c =   -----------------------------------------
%              sqrt(sum((Z(i,j)-z)^2)*sum((Y(i,j)-y)^2))
%                   i<j               i<j
% 
%            
%    Y(i,j) is the distance between observation i and j. y is mean(Y).
%    Z(i,j) is the distance between observation i and j at the combine
%    time and z = mean(Z).
% 
%    

function cluster
%MATLAB Tour Partial Function Help:  stat_con
%
% CLUSTER Construct clusters from LINKAGE output.
%    T = CLUSTER(Z, CUTOFF) constructs clusters from cluster tree Z.  Z
%    is a matrix of size M-1 by 3, generated by LINKAGE. CUTOFF is a
%    threshold for cutting the hierarchical tree generated by LINKAGE
%    into clusters. When 0 < CUTOFF < 1, clusters are formed when
%    inconsistent values are greater than CUTOFF (see INCONSISTENT).
%    When CUTOFF is an integer and CUTOFF >= 1, then CUTOFF is
%    considered as the maximum number of clusters to keep in the
%    hierachical tree generated by LINKAGE.
% 
%    T = CLUSTER(Z, CUTOFF, DEPTH) construct clusters from cluster
%    tree Z, with inconsistent value CUTOFF as the threshhold and
%    DEPTH as the depth in the inconsitent value computation.
% 
%    The output T is a vector of size M that contains cluster number
%    for each observation in the original data.
% 
%    

function clusterdata
%MATLAB Tour Partial Function Help:  stat_con
%
% CLUSTERDATA Construct clusters from data.
%    T = CLUSTERDATA(X, CUTOFF) construct clusters from a given data X.
%    X is a matrix of size M by N, treated as M observations of N
%    variables.  CUTOFF is a threshold for cutting the hierarchical
%    tree generated by LINKAGE into clusters. When 0 < CUTOFF < 1,
%    Clusters are formed when inconsistent values are greater than
%    CUTOFF (see INCONSISTENT). When CUTOFF is an integer and CUTOFF >= 1,
%    then CUTOFF is considered as the maximum number of clusters to
%    keep in the hierachical tree generated by LINKAGE.
% 
%    The output T is a vector of size M that contains cluster number
%    for each observation.
% 
%    T = CLUSTERDATA(X,CUTOFF) is the same as 
% 
%       Y = pdist(X,'euclid');
%       Z = linkage(Y, 'single');
%       T = cluster(Z, CUTOFF);
% 
%    Follow this sequence to use non-default parameters for PDIST and
%    LINKAGE.
%    
%    

function cordexch
%MATLAB Tour Partial Function Help:  stat_con
%
% CORDEXCH D-Optimal design of experiments - coordinate exchange algorithm.
%    CORDEXCH(NFACTORS,NRUNS,MODEL)  creates a d-optimal experimental
%    design using the coordinate exchange algorithm.
% 
%    [SETTINGS, X] = CORDEXCH(NFACTORS,NRUNS,MODEL) generates the
%    factor settings matrix, SETTINGS, and the associated design
%    matrix, X. The number of factors, NFACTORS, and desired 
%    number of runs, NRUNS. The optional string input, MODEL, 
%    controls the order of the regression model. By default,
%    CORDEXCH returns the design matrix for a linear additive 
%    model with a constant term. MODEL can be following strings:
%    interaction - includes constant, linear, and cross product terms.
%    quadratic - interactions plus squared terms.
%    purequadratic - includes constant, linear and squared terms.

function daugment
%MATLAB Tour Partial Function Help:  stat_con
%
% DAUGMENT Augment D-Optimal design.
%    DAUGMENT add NRUNS to an experimental design using the 
%    coordinate exchange algorithm.
% 
%    [SETTINGS, X] = DAUGMENT(STARTDES,NRUNS,MODEL) generates the
%    factor settings matrix, SETTINGS, and the associated design
%    matrix, X. The optional string input, MODEL, 
%    controls the order of the regression model. By default,
%    DAUGMENT returns the design matrix for a linear additive 
%    model with a constant term. MODEL can be following strings:
%    interaction - includes constant, linear, and cross product terms.
%    quadratic - interactions plus squared terms.
%    purequadratic - includes constant, linear and squared terms.

function dcovary
%MATLAB Tour Partial Function Help:  stat_con
%
% DCOVARY D-Optimal design with fixed covariates.
%    DCOVARY creates a D-Optimal design subject to the constraint of
%    fixed covariates for each run using the coordinate exchange
%    algorithm.
% 
%    [SETTINGS, X] = DCOVARY(NFACTORS,COVARIATES,MODEL) generates the
%    factor settings matrix, SETTINGS, and the associated design
%    matrix, X. The optional string input, MODEL, 
%    controls the order of the regression model. By default,
%    DCOVARY returns the design matrix for a linear additive 
%    model with a constant term. MODEL can be following strings:
%    interaction - includes constant, linear, and cross product terms.
%    quadratic - interactions plus squared terms.
%    purequadratic - includes constant, linear and squared terms.

function ff2n
%MATLAB Tour Partial Function Help:  stat_con
%
% FF2N   Two-level full-factorial design.
%    X = FF2N(N) creates a two-level full-factorial design, X.
%    N is the number of columns of X. The number of rows is 2^N.

function fullfact
%MATLAB Tour Partial Function Help:  stat_con
%
% FULLFACT Mixed-level full-factorial designs.
%     FULLFACT(LEVELS) outputs the factor settings for a full factorial
%    design. The vector LEVELS specifies the number of unique setting
%    in each column of the design.
%    Example: If LEVELS = [2 4 3], FULLFACT will generate a 24 run design
%    with 2 levels in the first column, 4 in the second column, and 3 in
%    the third column.

function hadamard
%MATLAB Tour Partial Function Help:  stat_con
%
% HADAMARD Hadamard matrix.
%    HADAMARD(N) is a Hadamard matrix of order N, that is,
%    a matrix H with elements 1 or -1 such that H'*H = N*EYE(N).
%    An N-by-N Hadamard matrix with N > 2 exists only if REM(N,4)=0.
%    This function handles only the cases where N, N/12 or N/20
%    is a power of 2.

function rowexch
%MATLAB Tour Partial Function Help:  stat_con
%
% ROWEXCH D-Optimal design of experiments (row exchange algorithm).
%    [SETTINGS, X] = ROWEXCH(NFACTORS,NRUNS,MODEL) generates the
%    factor settings matrix, SETTINGS, and the associated design
%    matrix, X. The number of factors, NFACTORS, and desired 
%    number of runs, NRUNS. The optional string input, MODEL, 
%    controls the order of the regression model. By default,
%    ROWEXCH returns the design matrix for a linear additive 
%    model with a constant term. MODEL can be following strings:
%    interaction - includes constant, linear, and cross product terms.
%    quadratic - interactions plus squared terms.
%    purequadratic - includes constant, linear and squared terms.

function capable
%MATLAB Tour Partial Function Help:  stat_con
%
% CAPABLE Capability indices.
%    CAPABLE(DATA,SPECS) returns the probability that a sample from
%    the process will fall outside the specifications, SPECS.
%    The assumptions are that the measured values in DATA are normally
%    distributed with constant mean and variance and the the measurements
%    are statistically independent.
% 
%    SPECS is a two element vector containing a lower and upper bound. If
%    there is no lower bound, then use -Inf. Similarly, for no upper bound
%    use Inf.
% 
%    [P, CP, CPK] = CAPABLE(DATA,SPECS) also returns the capability 
%    indices CP and CPK. 

function capaplot
%MATLAB Tour Partial Function Help:  stat_con
%
% CAPAPLOT Capability plot.
%    CAPAPLOT(DATA,SPECS) fits the observations in the vector DATA assuming a normal
%    distribution with unknown mean and variance and plots the distribution of 
%    a new observation (T distribution.) The part of the distribution between the 
%    lower and upper bounds contained in the two element vector, SPECS, is shaded
%    in the plot.
% 
%    [P, H] = CAPAPLOT(DATA,SPECS) returns the probability of the new observation
%    being within spec in P and handles to the plot elements in H.

function ewmaplot
%MATLAB Tour Partial Function Help:  stat_con
%
% EWMAPLOT Exponentially weighted moving average chart.
%    H = EWMAPLOT(DATA,LAMBDA,ALPHA,SPECS) produces an EWMA chart 
%    of the grouped responses in DATA. The rows of DATA contain
%    replicate observations taken at a given time. The rows
%    should be in time order.
% 
%    LAMBDA (optional) is the parameter that controls how much 
%    the current prediction is influenced by past observations. 
%    Higher values of LAMBDA give more weight to past observations. 
%    By default, LAMBDA = 0.4, and LAMBDA must be between 0 and 1. 
% 
%    ALPHA (optional) is the significance level of the upper and 
%    lower plotted confidence limits. ALPHA is 0.01 by default.
%    This means that 99% of the plotted points should fall 
%    between the control limits.
% 
%    SPECS (optional) is a two element vector for the lower and
%    upper specification limits of the response.
% 
%    H is a vector of handles to the plotted lines.

function histfit
%MATLAB Tour Partial Function Help:  stat_con
%
% HISTFIT Histogram with superimposed fitted normal density.
%    HISTFIT(DATA,NBINS) plots a histogram of the values in the vector DATA.
%    using NBINS bars in the histogram. With one input argument, NBINS is set 
%    to the square root of the number of elements in DATA. 

function normspec
%MATLAB Tour Partial Function Help:  stat_con
%
% NORMSPEC Plots normal density between specification limits.
%    NORMSPEC(SPECS,MU,SIGMA) plots the normal density between the lower and
%    upper bounds contained in SPECS. MU and SIGMA are the parameters of the
%    plotted distribution.
% 
%    [P, H] = NORMSPEC(SPECS,MU,SIGMA) returns the probability, P, of a sample
%    falling between the lower and upper limits. H is a handle to the line objects.
% 
%    If SPECS(1) is -Inf  there is no lower limit, and similarly if SPECS(2) = Inf
%    there is no upper limit. By default, MU and SIGMA are zero and one
%    respectively.     

function schart
%MATLAB Tour Partial Function Help:  stat_con
%
% SCHART S chart for monitoring the standard deviation.
%    SCHART(DATA,CONF,SPECS) produces an S chart of
%    the grouped responses in DATA. The rows of DATA contain
%    replicate observations taken a a given time. The rows
%    must be in time order.
% 
%    CONF (optional) is the confidence level of the upper and 
%    lower plotted confidence limits. CONF is 0.99 by default.
%    This means that 99% of the plotted points should fall 
%    between the control limits.
% 
%    SPECS (optional) is a two element vector for the lower and
%    upper specification limits of the response.
% 
%    OUTLIERS = SCHART(DATA,CONF,SPECS) returns  a vector of 
%    indices to the rows where the standard deviation of DATA is 
%    out of control.
% 
%    [OUTLIERS, H] = SCHART(DATA,CONF,SPECS) also returns a vector
%    of handles, H, to the plotted lines.

function xbarplot
%MATLAB Tour Partial Function Help:  stat_con
%
% XBARPLOT X-bar chart for monitoring the mean.
%    XBARPLOT(DATA,CONF,SPECS) produces an xbar chart of
%    the grouped responses in DATA. The rows of DATA contain
%    replicate observations taken a a given time. The rows
%    should be in time order.
% 
%    CONF (optional) is the confidence level of the upper and 
%    lower plotted confidence limits. CONF is 0.99 by default.
%    This means that 99% of the plotted points should fall 
%    between the control limits.
% 
%    SPECS (optional) is a two element vector for the lower and
%    upper specification limits of the response.
% 
%    OUTLIERS = XBARPLOT(DATA,CONF,SPECS) returns  a vector of 
%    indices to the rows where the mean of DATA is out of control.
% 
%    [OUTLIERS, H] = XBARPLOT(DATA,CONF,SPECS) also returns a vector
%    of handles, H, to the plotted lines.

function barttest
%MATLAB Tour Partial Function Help:  stat_con
%
% BARTTEST Bartlett's test for dimensionality of the data in X.
%    [NDIM, PROB, CHISQUARE] = BARTTEST(X,ALPHA) requires a data matrix X and
%    a significance probability, ALPHA. It returns the number of dimensions
%    necessary to explain the nonrandom variation in X. The hypothesis is that 
%    the number of dimensions is equal to the number of the largest unequal 
%    eigenvalues of the covariance matrix of X.
%    CHISQUARE is a vector of statistics for testing this hypothesis 
%    sequentially for one, two, three, etc. dimensions.
%    PROB is the vector of significance probabilities that correspond to each
%    element of CHISQUARE.

function pcacov
%MATLAB Tour Partial Function Help:  stat_con
%
%  PCACOV  Principal Component Analysis using the covariance matrix.
%    [PC, LATENT, EXPLAINED] = PCACOV(X) takes a the covariance matrix,
%    X, and returns the principal components in PC, the eigenvalues of
%    the covariance matrix of X in LATENT, and the percentage of the
%    total variance in the observations explained by each eigenvector 
%    in EXPLAINED.

function pcares
%MATLAB Tour Partial Function Help:  stat_con
%
% PCARES Residuals from a Principal Components Analysis.
%    RESIDUALS = PCARES(X,NDIM) takes a data matrix X and returns the
%    residuals obtained by retaining NDIM principal components of X.
%    Note that NDIM is a scalar and must be less than the number of
%    columns in X.

function princomp
%MATLAB Tour Partial Function Help:  stat_con
%
% PRINCOMP Principal Component Analysis (centered and scaled data).
%    [PC, SCORE, LATENT, TSQUARE] = PRINCOMP(X) takes a data matrix X and
%    returns the principal components in PC, the so-called Z-scores in SCORES,
%    the eigenvalues of the covariance matrix of X in LATENT, and Hotelling's
%    T-squared statistic for each data point in TSQUARE.

function classify
%MATLAB Tour Partial Function Help:  stat_con
%
% CLASSIFY Linear discriminant analysis.
%    CLASS = CLASSIFY(SAMPLE,TRAINING,GROUP) classifies each row
%    of the data in SAMPLE into one of the values of the vector
%    GROUP. GROUP contains integers from one to the number of 
%    groups in the training set, which is the matrix, TRAINING.
% 
%    SAMPLE and TRAINING must have the same number of columns.
%    TRAINING and GROUP must have the same number of rows.
%    CLASS is a vector with the same number of rows as SAMPLE.

function mahal
%MATLAB Tour Partial Function Help:  stat_con
%
%  MAHAL Mahalanobis distance.
%    MAHAL(Y,X) gives the Mahalanobis distance of each point in
%    Y from the sample in X. 
%    
%    The number of columns of Y must equal the number
%    of columns in X, but the number of rows may differ.
%    The number of rows must exceed the number of columns
%    in X.

function ranksum
%MATLAB Tour Partial Function Help:  stat_con
%
% RANKSUM Wilcoxon rank sum test that two populations are identical.
%    P = RANKSUM(X,Y,ALPHA) returns the significance probability
%    that the populations generating two independent samples, X and Y
%    are identical. X and Y are vectors but can have different lengths.
%    ALPHA is the desired level of significance and must be a scalar
%    between zero and one.
% 
%    [P, H] = RANKSUM(X,Y,ALPHA) also returns the result of the 
%    hypothesis test, H. H is zero if the difference in populations of
%    X and Y is not significantly different. H is one if the two
%    populations are significantly different. 
% 
%    P is the probability of observing a result equally or more 
%    extreme than the one using the data (X and Y) if the null  
%    hypothesis is true. If P is near zero, this casts doubt on
%    this hypothesis.

function signrank
%MATLAB Tour Partial Function Help:  stat_con
%
% SIGNRANK Wilcoxon signed rank test of equality of medians.
%    P = SIGNRANK(X,Y,ALPHA) returns the significance probability
%    that the medians of two matched samples, X and Y are equal.
%    X and Y must be vectors of equal length. ALPHA is the desired
%    level of significance. and must be a scalar between
%    zero and one.
% 
%    [P, H] = SIGNRANK(X,Y,ALPHA) also returns the result of the 
%    hypothesis test, H. H is zero if the difference in medians of
%    X and Y is not significantly different from zero. H is one if
%    the two medians are significantly different. 
% 
%    P is the probability of observing a result equally or more 
%    extreme than the one using the data (X and Y) if the null  
%    hypothesis is true. If P is near zero, this casts doubt on
%    this hypothesis.

function signtest
%MATLAB Tour Partial Function Help:  stat_con
%
% SIGNTEST Sign test.
%    P = SIGNTEST(X,Y,ALPHA) returns the significance probability
%    that the medians of two matched samples, X and Y are equal.
%    X and Y must be vectors of equal length. Y may also be a scalar.
%    In this case, SIGNTEST computes the probability that the median
%    of X is different from the constant, Y. ALPHA is the desired
%    level of significance and must be a scalar between
%    zero and one.
% 
%    [P, H] = SIGNTEST(X,Y,ALPHA) also returns the result of the 
%    hypothesis test, H. H is zero if the difference in medians of
%    X and Y is not significantly different from zero. H is one if
%    the two medians are significantly different. 
% 
%    P is the probability of observing a result equally or more 
%    extreme than the one using the data (X and Y) if the null  
%    hypothesis is true. If P is near zero, this casts doubt on
%    this hypothesis.

function ztest
%MATLAB Tour Partial Function Help:  stat_con
%
% ZTEST  Hypothesis test: Compares the sample average to a constant.
%    [H,SIG] = ZTEST(X,M,SIGMA,ALPHA,TAIL) performs a Z-test to determine
%    whether a sample from a normal distribution (in X) could have mean M 
%    when the standard deviation, SIGMA, is known.
%    ALPHA = 0.05 and TAIL = 0 by default.
% 
%    Null hypothesis is: "mean is equal to M".
%    For TAIL =  0, alternative: "mean is not M".
%    For TAIL =  1, alternative: "mean is greater than M."
%    For TAIL = -1, alternative: "mean is less than M."
% 
%    ALPHA is desired significance level. 
%    SIG is the probability of observing the given result by chance
%    given that the null hypothesis is true. Small values of SIG cast
%    doubt on the validity of the null hypothesis.
% 
%    H=0 => "Do not reject null hypothesis at significance level of alpha."
%    H=1 => "Reject null hypothesis at significance level of alpha."

function ttest
%MATLAB Tour Partial Function Help:  stat_con
%
% TTEST  Hypothesis test: Compares the sample average to a constant.
%    [H,SIG] = TTEST(X,M,ALPHA,TAIL) performs a T-test to determine
%    if a sample from a normal distribution (in X) could have mean M.
%    M = 0, ALPHA = 0.05 and TAIL = 0 by default.
% 
%    The Null hypothesis is: "mean is equal to M".
%    For TAIL=0,  alternative: "mean is not M".
%    For TAIL=1,  alternative: "mean is greater than M"
%    For TAIL=-1, alternative: "mean is less than M"
%    TAIL = 0 by default.
% 
%    ALPHA is desired significance level. 
%    SIG is the probability of observing the given result by chance
%    given that the null hypothesis is true. Small values of SIG cast
%    doubt on the validity of the null hypothesis.
%    H=0 => "Do not reject null hypothesis at significance level of alpha."
%    H=1 => "Reject null hypothesis at significance level of alpha."

function ttest2
%MATLAB Tour Partial Function Help:  stat_con
%
% TTEST2 Hypothesis test: Compares the averages of two samples.
%    [H,SIGNIFICANCE CI] = TTEST2(X,Y,ALPHA,TAIL) performs a t-test to  
%    determine whether two samples from a normal distribution
%    (with unknown but equal variances) could have the same mean. 
% 
%    The null hypothesis is: "means are equal".
%    For TAIL =  0  the alternative hypothesis is: "means are not equal."
%    For TAIL =  1, alternative: "mean of X is greater than mean of Y."
%    For TAIL = -1, alternative: "mean of X is less than mean of Y."
%    TAIL = 0 by default.
% 
%    ALPHA is desired significance level (ALPHA = 0.05 by default). 
%    SIGNIFICANCE is the probability of observing the given result by 
%    chance given that the null hypothesis is true. Small values of 
%    SIGNIFICANCE cast doubt on the validity of the null hypothesis.
%    H=0 => "Do not reject null hypothesis at significance level of alpha."
%    H=1 => "Reject null hypothesis at significance level of alpha."

function boxplot
%MATLAB Tour Partial Function Help:  stat_con
%
% BOXPLOT Display boxplots of a data sample.
%    BOXPLOT(X,NOTCH,SYM,VERT,WHIS) produces a box and whisker plot for
%    each column of X. The box has lines at the lower quartile, median, 
%    and upper quartile values. The whiskers are lines extending from 
%    each end of the box to show the extent of the rest of the data. 
%    Outliers are data with values beyond the ends of the whiskers.
%  
%    NOTCH = 1 produces a notched-box plot. Notches represent a robust 
%    estimate of the uncertainty about the means for box to box comparison.
%    NOTCH = 0 (default) produces a rectangular box plot. 
%    SYM sets the symbol for the outlier values if any (default='+'). 
%    VERT = 0 makes the boxes horizontal (default: VERT = 1, for vertical).
%    WHIS defines the length of the whiskers as a function of the IQR
%    (default = 1.5). If WHIS = 0 then BOXPLOT displays all data  
%    values outside the box using the plotting symbol, SYM.   
% 
%    If there are no data outside the whisker, then, there is a dot at the 
%    bottom whisker, the dot color is the same as the whisker color. If
%    a whisker falls inside the box, we choose not to draw it. To force
%    it to be drawn at the right place, set whissw = 1.
% 
%    BOXPLOT calls BOXUTIL to do the actual plotting.

function fsurfht
%MATLAB Tour Partial Function Help:  stat_con
%
% FSURFHT Interactive contour plot of a function.
%    FSURFHT(FUN,XLIM,YLIM) is an interactive contour plot of the function
%    specified by the text variable FUN.  The x-axis limits are specified 
%    by XLIM = [XMIN XMAX] and the y-axis limits specified by YLIM.
%    FSURFHT(FUN,XLIM,YLIM,VARARGIN) allows for an arbitrary number of
%    optional parameters that you can supply to the function FUN. The first two
%    arguments of FUN are the x-axis variable and y-axis variable, respectively. 
% 
%    There are vertical and horizontal reference lines on the plot whose 
%    intersection defines the current x-value and y-value. You can drag
%    these dotted white reference lines and watch the calculated z-values (at
%    the top of the plot) update simultaneously. Alternatively, you can get a 
%    specific z-value by typing the x-value and y-value into editable text
%    fields on the x-axis and y-axis respectively. 

function gline
%MATLAB Tour Partial Function Help:  stat_con
%
% GLINE Draw a line in a figure interactively.
%    GLINE(FIG) draws a line segment by clicking the mouse at the
%    two end-points of the line segment in the figure FIG.
%    A rubberband line tracks the mouse movement. 
%    H = GLINE(FIG) Returns the handle to the line.
% 
%    GLINE with no input arguments draws in the current figure.

function gname
%MATLAB Tour Partial Function Help:  stat_con
%
% GNAME  Labels plotted points with their case names or case number.
%    GNAME('CASES') displays the graph window, puts up a
%    cross-hair, and waits for a mouse button or keyboard key to be
%    pressed.  Position the cross-hair with the mouse and click once
%    near each point that you want to label. When you are done,
%    press the return or enter key and the labels will appear at each 
%    point that you clicked. CASES is a string matrix. Each row of
%    CASES is the case name of a point. 
% 
%    GNAME with no arguments labels each case with its case number. 
%    
%    HH = GNAME('CASES',LINE_HANDLE) returns a vector of handles
%    to the text objects on the plot. Use the scalar,LINE_HANDLE, to
%    identify the correct line if there is more than one line object 
%    on the plot.
% 
%    

function lsline
%MATLAB Tour Partial Function Help:  stat_con
%
%  LSLINE Add least-squares fit line to scatter plot.
%    LSLINE superimposes the least squares line on each line object
%    in the current axis (Except LineStyles '-','--','.-'.)
%  
%    H = LSLINE returns the handle to the line object(s) in H.
%    
%    

function normplot
%MATLAB Tour Partial Function Help:  stat_con
%
% NORMPLOT Displays a normal probability plot.
%    H = NORMPLOT(X) makes a normal probability plot of the  
%    data in X. For matrix, X, NORMPLOT displays a plot for each column.
%    H is a handle to the plotted lines.
%    
%    The purpose of a normal probability plot is to graphically assess
%    whether the data in X could come from a normal distribution. If the
%    data are normal the plot will be linear. Other distribution types 
%    will introduce curvature in the plot.  

function qqplot
%MATLAB Tour Partial Function Help:  stat_con
%
% QQPLOT Displays an empirical quantile-quantile plot.
%    QQPLOT(X,Y) makes an empirical QQ-plot of the quantiles of
%    the data set X versus the quantiles of the data set Y.
%    H = QQPLOT(X,Y,PVEC) allows you to specify the plotted quantiles in 
%    the vector PVEC. H is a handle to the plotted lines. 
% 
%    The default quantiles are those of the smaller data set.
% 
%    The purpose of the quantile-quantile plot is to determine whether 
%    the samples in X and Y come from the same distribution type (parameter
%    values may be different.) If the samples do come from the same
%    distribution, the plot will be linear.  

function refcurve
%MATLAB Tour Partial Function Help:  stat_con
%
% REFCURVE Add a reference curve (polynomial) to a plot.
%    REFCURVE(P) adds a line with the given polynomial coefficients 
%    to the current figure.
%    H = REFCURVE(P) returns the handle to the line object
%    in H.
%    REFCURVE with no arguments plots the function Y = 0.
%    Example: 
%        y = p(1)*x^d + p(2)*x^(d-1) + ... + p(d)*x + p(d+1)
%        Shows a polynomial of degree, d.
%        Note that p(1) goes with the highest order term.
% 
%    

function refline
%MATLAB Tour Partial Function Help:  stat_con
%
% REFLINE Add a reference line to a plot.
%    REFLINE(SLOPE,INTERCEPT) adds a line with the given SLOPE and
%    INTERCEPT to the current figure.
% 
%    REFLINE(SLOPE) where SLOPE is a two element vector adds the line
%         y = SLOPE(2) + SLOPE(1)*x 
%    to the figure. (See POLYFIT.)
% 
%    H = REFLINE(SLOPE,INTERCEPT) returns the handle to the line object
%    in H.
% 
%    REFLINE with no input arguments superimposes the least squares line on 
%    each line object in the current figure (Except LineStyles '-','--','.-'.)
% 
%    

function surfht
%MATLAB Tour Partial Function Help:  stat_con
%
% SURFHT Interactive contour plot of a data grid.
%    SURFHT(Z) is an interactive contour plot of the matrix Z treating the
%    values in Z as height above the plane. The x-values are the column 
%    indices of Z while the y-values are the row indices of Z.
%    SURFHT(x,y,Z), where x and y are vectors specify the x and y-axes on the
%    contour plot. The length of x and y must match the number of rows in Z.
% 
%    There are vertical and horizontal reference lines on the plot whose 
%    intersection defines the current x-value and y-value. You can drag
%    these dotted white reference lines and watch the interpolated z-values
%    (at the top of the plot) update simultaneously. Alternatively, you can 
%    get a specific interpolated z-value by typing the x-value and y-value  
%    into editable text fields on the x-axis and y-axis respectively. 

function weibplot
%MATLAB Tour Partial Function Help:  stat_con
%
% WEIBPLOT Weibull probability plot.
%    H = WEIBPLOT(X) displays a Weibull probability plot of the  
%    data in X. For matrix, X, WEIBPLOT displays a plot for each column.
%    H is a handle to the plotted lines.
%    
%    The purpose of a Weibull probability plot is to graphically assess
%    whether the data in X could come from a Weibull distribution. If the
%    data are Weibull the plot will be linear. Other distribution types 
%    will introduce curvature in the plot.  

function disttool
%MATLAB Tour Partial Function Help:  stat_con
%
% DISTTOOL Demonstration of many probability distributions.
%    DISTTOOL creates interactive plots of probability distributions.
%    This is a demo that displays a plot of the cdf or pdf of
%    the distributions in the Statistics Toolbox.
% 
%    Use popup menus to change the distibution (Normal to Binomial) or
%    the function (cdf to pdf). 
% 
%    You can change the parameters of the distribution by typing
%    a new value or by moving a slider.    
% 
%    You can interactively calculate new values by dragging a reference 
%    line across the plot.
% 
%    Call DISTTOOL without arguments.

function polytool
%MATLAB Tour Partial Function Help:  stat_con
%
% POLYTOOL Fits a polynomial to (x,y) data and displays an interactive graph.
%    POLYTOOL(X,Y,N,ALPHA) is a prediction plot that provides a Nth degree
%    polynomial curve fit to (x,y) data. It plots a 100(1 - ALPHA) percent
%    global confidence interval for predictions as two red curves. The
%    default value for N is 1 and the default value for ALPHA is 0.05,
%    which produces a linear model and 95% confidence intervals respectively. 
% 
%    POLYTOOL(X,Y,N,ALPHA,XNAME,YNAME) The optional inputs XNAME and 
%    YNAME contain strings for the X and Y variables respectively.
% 
%    H = POLYTOOL(X,Y,N,ALPHA,XNAME,YNAME) outputs a vector of handles, H,
%    to the line objects in the plot.
% 
%    You can drag the dotted white reference line and watch the predicted
%    values update simultaneously. Alternatively, you can get a specific
%    prediction by typing the "X" value into an editable text field.
%    A pop-up menu at the top allows you to change the degree of the 
%    polynomial fit. Use the pop-up menu labeled Export to move 
%    specified variables to the base workspace.

function randtool
%MATLAB Tour Partial Function Help:  stat_con
%
% RANDTOOL Demonstration of many random number generators.
%    RANDTOOL(ACTION) creates a histogram of random samples from many
%    distributions. This is a demo that displays a histograms of random
%    samples from the distributions in the Statistics Toolbox. 
% 
%    Change the parameters of the distribution by typing in a new
%    value or by moving a slider.
% 
%    Output the current sample to a variable in the workspace by pressing
%    the output button.
% 
%    Change the sample size by typing any positive integer in the
%    sample size edit box.
% 
%    Change the distribution type using the popup menu.

function rsmdemo
%MATLAB Tour Partial Function Help:  stat_con
%
% RSMDEMO Demo of design of experiments and surface fitting.
%    RSMDEMO Creates a GUI that simulates a chemical reaction.
%    To start, you have a budget of 13 test reactions. Try to find out how
%    changes in each reactant affect the reaction rate. Determine the 
%    reactant settings that maximize the reaction rate. Estimate the
%    run-to-run variability of the reaction.
% 
%    Now run a designed experiment using the model popup. Compare your
%    previous results with the output from response surface modeling or
%    nonlinear modeling of the reaction.
% 
%    The GUI has the following elements:
%    1) A RUN button to perform one reactor run at the current settings.
%    2) An Export button to export the X and Y data to the base workspace.
%    3) Three sliders with associated data entry boxes to control the 
%       partial pressures of the chemical reactants: Hydrogen, n-Pentane,
%       and Isopentane.
%    4) A text box to report the reaction rate.
%    5) A text box to keep track of the number of test reactions you have
%       left.
% 
%    

function tblread
%MATLAB Tour Partial Function Help:  stat_con
%
% TBLREAD Retrieves tabular data from the file system.
%    [DATA, VARNAMES, CASENAMES] = TBLREAD retrieves
%    data from the file selected with interactively with variable names in
%    the first row, case names in the first column and data starting in  
%    the (2,2) position, using a space as the delimiting character.
%    [DATA, VARNAMES, CASENAMES] = TBLREAD(FILENAME) retrieves
%    data from the file named FILENAME with variable names in the first row,
%    case names in the first column and data starting in the (2,2) position, 
%    using a space as the delimiting character.
%    [DATA, VARNAMES, CASENAMES] = TBLREAD(FILENAME,DELIMITER) retrieves
%    data from a file with variable names in the first row, case names
%    in the first column and data starting in the (2,2) position. FILENAME is 
%    the complete path to the desired file.
% 
%    Allowable values of DELIMITER can be any of the following:
%         ' ', '\t', ',', ';', '|' or their corresponding string name 
%         'space', 'tab', 'comma', 'semi', 'bar'; 'space' is the default. 
%    VARNAMES is a string matrix containing the variable names 
%    in the first row.
%    CASENAMES is a string matrix containing the names of each
%    case in the first column.
%    DATA is a numeric matrix with a value for each variable-case
%    pair.

function tblwrite
%MATLAB Tour Partial Function Help:  stat_con
%
% TBLWRITE Writes data in tabular form to the file system.
%    TBLWRITE(DATA, VARNAMES, CASENAMES, FILENAME,DELIMITER) writes
%    a space delimited file with variable names in the first row,
%    case names in the first column and data in columns under each
%    variable name. FILENAME is the complete path to the desired file.
%    VARNAMES is a string matrix containing the variable names. 
%    CASENAMES is a string matrix containing the names of each observation.
%    DATA is a numeric matrix with a value for each variable-observation
%    pair.
%    DELIMITER can be any of the following: ' ', '\t', ',', ';', '|' or their
%    corresponding string names 'space', 'tab', 'comma', 'semi', 'bar'. If
%    it is not given, the default is set to be ' ' (space).

function caseread
%MATLAB Tour Partial Function Help:  stat_con
%
% CASEREAD Reads casenames from a file.
%    CASEREAD(FILENAME) returns a string matrix of names. FILENAME is 
%    the complete path to the desired file. CASEREAD expects one line per
%    case in the file.
% 
%    CASEREAD without inputs displays the File Open dialog box allowing
%    interactive choice of the file.

function casewrite
%MATLAB Tour Partial Function Help:  stat_con
%
% CASEWRITE Writes casenames from a string matrix to a file.
%    CASEWRITE(STRMAT,FILENAME) writes a list of names to a file, one per line. 
%    FILENAME is the complete path to the desired file. If FILENAME does not
%    include directory information, the file will appear in the current directory.
% 
%    CASEWRITE without inputs displays the File Open dialog box allowing
%    interactive naming of the file.

